---
title: wls domain partition
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage domain partitions in an WebLogic 12.2.1 domain.

## Attributes



Attribute Name                                                                                                       | Short Description                                                                                                                                                                                                           |
-------------------------------------------------------------------------------------------------------------------- | --------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
[batch_jobs_data_source_jndi_name](#wls_domain_partition_batch_jobs_data_source_jndi_name)                           | The JNDI name of the Batch runtime's JobRepository data source, which will be used to store data for Batch jobs submitted from applications deployed to the partition.                                                      |
[batch_jobs_executor_service_name](#wls_domain_partition_batch_jobs_executor_service_name)                           | The name of the application-scoped Managed Executor Service instance that will be used to run Batch jobs that are submitted from applications deployed to the partition.                                                    |
[data_source_for_job_scheduler](#wls_domain_partition_data_source_for_job_scheduler)                                 | The data source required to support the persistence of jobs scheduled with the job scheduler.                                                                                                                               |
[domain](#wls_domain_partition_domain)                                                                               | With this parameter, you identify the domain, where your objects is in.                                                                                                                                                     |
[domain_partition_name](#wls_domain_partition_domain_partition_name)                                                 | The name of the domain partition.                                                                                                                                                                                           |
[eager_tracking_of_resource_metrics_enabled](#wls_domain_partition_eager_tracking_of_resource_metrics_enabled)       | Determines if tracking of resource consumption metrics of this Partition is initiated eagerly from the time the Partition is started, or if it is initiated lazily on first access of PartitionResourceMetricsRuntimeMBean. |
[ensure](#wls_domain_partition_ensure)                                                                               | The basic property that the resource should be in.                                                                                                                                                                          |
[graceful_shutdown_timeout](#wls_domain_partition_graceful_shutdown_timeout)                                         | The number of seconds a graceful shutdown operation waits before forcing a shut down.                                                                                                                                       |
[ignore_sessions_during_shutdown](#wls_domain_partition_ignore_sessions_during_shutdown)                             | Indicates whether a graceful shutdown operation drops all HTTP sessions immediately.                                                                                                                                        |
[job_scheduler_table_name](#wls_domain_partition_job_scheduler_table_name)                                           | The table name to use for storing timers active with the Job Scheduler.                                                                                                                                                     |
[max_concurrent_long_running_requests](#wls_domain_partition_max_concurrent_long_running_requests)                   | The maximum number of running long-running requests that can be submitted to all the Managed Executor Services or Managed Scheduled Executor Services in the partition on the current server.                               |
[max_concurrent_new_threads](#wls_domain_partition_max_concurrent_new_threads)                                       | The maximum number of running threads that can be created by all the Managed Thread Factories in the partition on the current server.                                                                                       |
[name](#wls_domain_partition_name)                                                                                   | The name.                                                                                                                                                                                                                   |
[notes](#wls_domain_partition_notes)                                                                                 | Optional information that you can include to describe this configuration.                                                                                                                                                   |
[parallel_deploy_application_modules](#wls_domain_partition_parallel_deploy_application_modules)                     | Determines if the modules of applications will be deployed in parallel.                                                                                                                                                     |
[parallel_deploy_applications](#wls_domain_partition_parallel_deploy_applications)                                   | Determines if applications will be deployed in parallel.                                                                                                                                                                    |
[partition_id](#wls_domain_partition_partition_id)                                                                   | The ID for this partition.                                                                                                                                                                                                  |
[partition_life_cycle_timeout_val](#wls_domain_partition_partition_life_cycle_timeout_val)                           | The number of seconds a force shutdown operation waits before timing out.                                                                                                                                                   |
[partition_work_manager](#wls_domain_partition_partition_work_manager)                                               | The partition-level work manager policy set by the system administrator for this partition.                                                                                                                                 |
[partition_work_manager_ref](#wls_domain_partition_partition_work_manager_ref)                                       | A reference to a partition-level work manager policy set by the system administrator.                                                                                                                                       |
[primary_identity_domain](#wls_domain_partition_primary_identity_domain)                                             | The partition's primary identity domain.                                                                                                                                                                                    |
[provider](#wls_domain_partition_provider)                                                                           | resource.                                                                                                                                                                                                                   |
[rcm_historical_data_buffer_limit](#wls_domain_partition_rcm_historical_data_buffer_limit)                           | The maximum number of elements retained for monitoring RCM usage requests over time.                                                                                                                                        |
[realm](#wls_domain_partition_realm)                                                                                 | The security realm for this partition.                                                                                                                                                                                      |
[resource_deployment_plan](#wls_domain_partition_resource_deployment_plan)                                           | The contents of this resource's deployment plan, returned as a byte[] containing the XML.                                                                                                                                   |
[resource_deployment_plan_external_descriptors](#wls_domain_partition_resource_deployment_plan_external_descriptors) | A zip file containing the external descriptors referenced in the deployment plan.                                                                                                                                           |
[resource_deployment_plan_path](#wls_domain_partition_resource_deployment_plan_path)                                 | The resource deployment plan path.                                                                                                                                                                                          |
[resource_manager](#wls_domain_partition_resource_manager)                                                           | The resource manager policy assigned to the partition.                                                                                                                                                                      |
[resource_manager_ref](#wls_domain_partition_resource_manager_ref)                                                   | A resource manager reference from the resource management.                                                                                                                                                                  |
[root_file_system](#wls_domain_partition_root_file_system)                                                           | The full path to the root of this file subsystem of the partition.                                                                                                                                                          |
[startup_timeout](#wls_domain_partition_startup_timeout)                                                             | The timeout value for a partition's start and resume operations.                                                                                                                                                            |
[systemfs_create_on_demand](#wls_domain_partition_systemfs_create_on_demand)                                         | Specifies whether the file system should be created on-demand when the partition is first started.                                                                                                                          |
[systemfs_notes](#wls_domain_partition_systemfs_notes)                                                               | Optional information that you can include to describe this configuration.                                                                                                                                                   |
[systemfs_preserved](#wls_domain_partition_systemfs_preserved)                                                       | Specifies whether the file system should be preserved when the partition is deleted.                                                                                                                                        |
[systemfs_tags](#wls_domain_partition_systemfs_tags)                                                                 | Return all tags on this Configuration MBean
                                                                                                                                                                                |
[tags](#wls_domain_partition_tags)                                                                                   | Return all tags on this Configuration MBean
                                                                                                                                                                                |
[timeout](#wls_domain_partition_timeout)                                                                             | Timeout for applying a resource.                                                                                                                                                                                            |
[upload_directory_name](#wls_domain_partition_upload_directory_name)                                                 | The directory path on the Administration Server where the uploaded applications for this partition are placed.                                                                                                              |
[virtual_target](#wls_domain_partition_virtual_target)                                                               | The virtual target for the domain partition
                                                                                                                                                                                |




### batch_jobs_data_source_jndi_name<a name='wls_domain_partition_batch_jobs_data_source_jndi_name'>

The JNDI name of the Batch runtime's JobRepository data source, which will be used to store data for Batch jobs submitted from applications deployed to the partition. When a Java EE component submits a Batch job, the Batch runtime updates the JobRepository tables using this data source, which is obtained by looking up the data source's JNDI name.

An example on how to use this:

    wls_domain_partition {a_wls_domain_partition :
       ...
       batch_jobs_data_source_jndi_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain_partition:batch_jobs_data_source_jndi_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_domain_partition](#attributes)


### batch_jobs_executor_service_name<a name='wls_domain_partition_batch_jobs_executor_service_name'>

The name of the application-scoped Managed Executor Service instance that will be used to run Batch jobs that are submitted from applications deployed to the partition. A Managed Executor Service Template by the same name must exist for the domain when a Batch job is submitted in the partition. If this name returns null, then the Batch runtime will use the default Java EE Managed Executor Service that is bound to the default JNDI name of: <code>java:comp/DefaultManagedExecutorService</code>.

An example on how to use this:

    wls_domain_partition {a_wls_domain_partition :
       ...
       batch_jobs_executor_service_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain_partition:batch_jobs_executor_service_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_domain_partition](#attributes)


### data_source_for_job_scheduler<a name='wls_domain_partition_data_source_for_job_scheduler'>

The data source required to support the persistence of jobs scheduled with the job scheduler.

An example on how to use this:

    wls_domain_partition {a_wls_domain_partition :
       ...
       data_source_for_job_scheduler => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain_partition:data_source_for_job_scheduler']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_domain_partition](#attributes)


### domain<a name='wls_domain_partition_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.


[Back to overview of wls_domain_partition](#attributes)


### domain_partition_name<a name='wls_domain_partition_domain_partition_name'>

The name of the domain partition.


[Back to overview of wls_domain_partition](#attributes)


### eager_tracking_of_resource_metrics_enabled<a name='wls_domain_partition_eager_tracking_of_resource_metrics_enabled'>

Determines if tracking of resource consumption metrics of this Partition is initiated eagerly from the time the Partition is started, or if it is initiated lazily on first access of PartitionResourceMetricsRuntimeMBean.

An example on how to use this:

    wls_domain_partition {a_wls_domain_partition :
       ...
       eager_tracking_of_resource_metrics_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain_partition:eager_tracking_of_resource_metrics_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_domain_partition](#attributes)


### ensure<a name='wls_domain_partition_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 
[Back to overview of wls_domain_partition](#attributes)


### graceful_shutdown_timeout<a name='wls_domain_partition_graceful_shutdown_timeout'>

The number of seconds a graceful shutdown operation waits before forcing a shut down. A graceful shutdown gives WebLogic Server subsystems time to complete certain application processing currently in progress. If subsystems are unable to complete processing within the number of seconds that you specify here, the partition will force shutdown automatically. <p/> A value of <code>0</code> means that the partition will wait indefinitely for a graceful shutdown to complete. <p/> The graceful shutdown timeout applies only to graceful shutdown operations.

An example on how to use this:

    wls_domain_partition {a_wls_domain_partition :
       ...
       graceful_shutdown_timeout => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain_partition:graceful_shutdown_timeout']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_domain_partition](#attributes)


### ignore_sessions_during_shutdown<a name='wls_domain_partition_ignore_sessions_during_shutdown'>

Indicates whether a graceful shutdown operation drops all HTTP sessions immediately. If this is set to <code>false</code>, a graceful shutdown operation waits for HTTP sessions to complete or timeout.

An example on how to use this:

    wls_domain_partition {a_wls_domain_partition :
       ...
       ignore_sessions_during_shutdown => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain_partition:ignore_sessions_during_shutdown']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_domain_partition](#attributes)


### job_scheduler_table_name<a name='wls_domain_partition_job_scheduler_table_name'>

The table name to use for storing timers active with the Job Scheduler.

An example on how to use this:

    wls_domain_partition {a_wls_domain_partition :
       ...
       job_scheduler_table_name => 'WEBLOGIC_TIMERS'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain_partition:job_scheduler_table_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_domain_partition](#attributes)


### max_concurrent_long_running_requests<a name='wls_domain_partition_max_concurrent_long_running_requests'>

The maximum number of running long-running requests that can be submitted to all the Managed Executor Services or Managed Scheduled Executor Services in the partition on the current server.

An example on how to use this:

    wls_domain_partition {a_wls_domain_partition :
       ...
       max_concurrent_long_running_requests => '50'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain_partition:max_concurrent_long_running_requests']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_domain_partition](#attributes)


### max_concurrent_new_threads<a name='wls_domain_partition_max_concurrent_new_threads'>

The maximum number of running threads that can be created by all the Managed Thread Factories in the partition on the current server.

An example on how to use this:

    wls_domain_partition {a_wls_domain_partition :
       ...
       max_concurrent_new_threads => '50'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain_partition:max_concurrent_new_threads']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_domain_partition](#attributes)


### name<a name='wls_domain_partition_name'>

The name.


[Back to overview of wls_domain_partition](#attributes)


### notes<a name='wls_domain_partition_notes'>

Optional information that you can include to describe this configuration.  WebLogic Server saves this note in the domain's configuration file (<code>config.xml</code>) as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  Note: If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds.

An example on how to use this:

    wls_domain_partition {a_wls_domain_partition :
       ...
       notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain_partition:notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_domain_partition](#attributes)


### parallel_deploy_application_modules<a name='wls_domain_partition_parallel_deploy_application_modules'>

Determines if the modules of applications will be deployed in parallel.  This setting can be overridden at the per-application level. See {@link AppDeploymentMBean#isParallelDeployModules()}

An example on how to use this:

    wls_domain_partition {a_wls_domain_partition :
       ...
       parallel_deploy_application_modules => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain_partition:parallel_deploy_application_modules']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_domain_partition](#attributes)


### parallel_deploy_applications<a name='wls_domain_partition_parallel_deploy_applications'>

Determines if applications will be deployed in parallel.

An example on how to use this:

    wls_domain_partition {a_wls_domain_partition :
       ...
       parallel_deploy_applications => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain_partition:parallel_deploy_applications']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_domain_partition](#attributes)


### partition_id<a name='wls_domain_partition_partition_id'>

The ID for this partition.

An example on how to use this:

    wls_domain_partition {a_wls_domain_partition :
       ...
       partition_id => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain_partition:partition_id']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_domain_partition](#attributes)


### partition_life_cycle_timeout_val<a name='wls_domain_partition_partition_life_cycle_timeout_val'>

The number of seconds a force shutdown operation waits before timing out. If the operation does not complete within the configured timeout period, the partition will shutdown automatically if the state of the server at that time was <code>SHUTTING_DOWN</code>. <p/> A value of <code>0</code> means that the partition will wait indefinitely for the life cycle operation to complete.

An example on how to use this:

    wls_domain_partition {a_wls_domain_partition :
       ...
       partition_life_cycle_timeout_val => '30'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain_partition:partition_life_cycle_timeout_val']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_domain_partition](#attributes)


### partition_work_manager<a name='wls_domain_partition_partition_work_manager'>

The partition-level work manager policy set by the system administrator for this partition.

An example on how to use this:

    wls_domain_partition {a_wls_domain_partition :
       ...
       partition_work_manager => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain_partition:partition_work_manager']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_domain_partition](#attributes)


### partition_work_manager_ref<a name='wls_domain_partition_partition_work_manager_ref'>

A reference to a partition-level work manager policy set by the system administrator.

An example on how to use this:

    wls_domain_partition {a_wls_domain_partition :
       ...
       partition_work_manager_ref => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain_partition:partition_work_manager_ref']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_domain_partition](#attributes)


### primary_identity_domain<a name='wls_domain_partition_primary_identity_domain'>

The partition's primary identity domain.

An example on how to use this:

    wls_domain_partition {a_wls_domain_partition :
       ...
       primary_identity_domain => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain_partition:primary_identity_domain']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_domain_partition](#attributes)


### provider<a name='wls_domain_partition_provider'>

The specific backend to use for this `wls_domain_partition`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: 


[Back to overview of wls_domain_partition](#attributes)


### rcm_historical_data_buffer_limit<a name='wls_domain_partition_rcm_historical_data_buffer_limit'>

The maximum number of elements retained for monitoring RCM usage requests over time.

An example on how to use this:

    wls_domain_partition {a_wls_domain_partition :
       ...
       rcm_historical_data_buffer_limit => '250'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain_partition:rcm_historical_data_buffer_limit']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_domain_partition](#attributes)


### realm<a name='wls_domain_partition_realm'>

The security realm for this partition.

An example on how to use this:

    wls_domain_partition {a_wls_domain_partition :
       ...
       realm => 'a_value'
       ...
    }


[Back to overview of wls_domain_partition](#attributes)


### resource_deployment_plan<a name='wls_domain_partition_resource_deployment_plan'>

The contents of this resource's deployment plan, returned as a byte[] containing the XML.

An example on how to use this:

    wls_domain_partition {a_wls_domain_partition :
       ...
       resource_deployment_plan => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain_partition:resource_deployment_plan']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_domain_partition](#attributes)


### resource_deployment_plan_external_descriptors<a name='wls_domain_partition_resource_deployment_plan_external_descriptors'>

A zip file containing the external descriptors referenced in the deployment plan.

An example on how to use this:

    wls_domain_partition {a_wls_domain_partition :
       ...
       resource_deployment_plan_external_descriptors => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain_partition:resource_deployment_plan_external_descriptors']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_domain_partition](#attributes)


### resource_deployment_plan_path<a name='wls_domain_partition_resource_deployment_plan_path'>

The resource deployment plan path.

An example on how to use this:

    wls_domain_partition {a_wls_domain_partition :
       ...
       resource_deployment_plan_path => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain_partition:resource_deployment_plan_path']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_domain_partition](#attributes)


### resource_manager<a name='wls_domain_partition_resource_manager'>

The resource manager policy assigned to the partition.

An example on how to use this:

    wls_domain_partition {a_wls_domain_partition :
       ...
       resource_manager => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain_partition:resource_manager']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_domain_partition](#attributes)


### resource_manager_ref<a name='wls_domain_partition_resource_manager_ref'>

A resource manager reference from the resource management.

An example on how to use this:

    wls_domain_partition {a_wls_domain_partition :
       ...
       resource_manager_ref => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain_partition:resource_manager_ref']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_domain_partition](#attributes)


### root_file_system<a name='wls_domain_partition_root_file_system'>

The full path to the root of this file subsystem of the partition.

An example on how to use this:

    wls_domain_partition {a_wls_domain_partition :
       ...
       root_file_system => 'a_value'
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_domain_partition](#attributes)


### startup_timeout<a name='wls_domain_partition_startup_timeout'>

The timeout value for a partition's start and resume operations. If the partition fails to start within the timeout period, it will force a shutdown. <p/> A value of <code>0</code> means that the server will wait indefinitely for the operation to complete.

An example on how to use this:

    wls_domain_partition {a_wls_domain_partition :
       ...
       startup_timeout => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain_partition:startup_timeout']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_domain_partition](#attributes)


### systemfs_create_on_demand<a name='wls_domain_partition_systemfs_create_on_demand'>

Specifies whether the file system should be created on-demand when the partition is first started.

An example on how to use this:

    wls_domain_partition {a_wls_domain_partition :
       ...
       systemfs_create_on_demand => '1'
       ...
    }

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_domain_partition](#attributes)


### systemfs_notes<a name='wls_domain_partition_systemfs_notes'>

Optional information that you can include to describe this configuration.  WebLogic Server saves this note in the domain's configuration file (<code>config.xml</code>) as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  Note: If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds.

An example on how to use this:

    wls_domain_partition {a_wls_domain_partition :
       ...
       systemfs_notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain_partition:systemfs_notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_domain_partition](#attributes)


### systemfs_preserved<a name='wls_domain_partition_systemfs_preserved'>

Specifies whether the file system should be preserved when the partition is deleted.

An example on how to use this:

    wls_domain_partition {a_wls_domain_partition :
       ...
       systemfs_preserved => '1'
       ...
    }

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_domain_partition](#attributes)


### systemfs_tags<a name='wls_domain_partition_systemfs_tags'>

Return all tags on this Configuration MBean

An example on how to use this:

    wls_domain_partition {a_wls_domain_partition :
       ...
       systemfs_tags => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain_partition:systemfs_tags']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_domain_partition](#attributes)


### tags<a name='wls_domain_partition_tags'>

Return all tags on this Configuration MBean

An example on how to use this:

    wls_domain_partition {a_wls_domain_partition :
       ...
       tags => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain_partition:tags']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_domain_partition](#attributes)


### timeout<a name='wls_domain_partition_timeout'>

Timeout for applying a resource.

To be sure no Puppet operation, hangs a Puppet daemon, all operations have a timeout. When this timeout
expires, Puppet will abort the current operation and signal an error in the Puppet run.

With this parameter, you can specify the length of the timeout. The value is specified in seconds. In
this example, the `timeout`  is set to `600`  seconds.

    wls_server{'my_server':
      ...
      timeout => 600,
    }

The default value for `timeout` is 120 seconds.


[Back to overview of wls_domain_partition](#attributes)


### upload_directory_name<a name='wls_domain_partition_upload_directory_name'>

The directory path on the Administration Server where the uploaded applications for this partition are placed.

An example on how to use this:

    wls_domain_partition {a_wls_domain_partition :
       ...
       upload_directory_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_domain_partition:upload_directory_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_domain_partition](#attributes)


### virtual_target<a name='wls_domain_partition_virtual_target'>

The virtual target for the domain partition

An example on how to use this:

    wls_domain_partition {a_wls_domain_partition :
       ...
       virtual_target => ['target_1','target_2']
       ...
    }


[Back to overview of wls_domain_partition](#attributes)

