---
title: wls foreign server object
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage a foreign server object in a JMS Module of a WebLogic domain.

Here is an example on how you should use this:

    wls_foreign_server_object { 'jmsClusterModule:Jboss:CF':
      ensure         => 'present',
      localjndiname  => 'jms/jboss/CF',
      object_type    => 'connectionfactory',
      remotejndiname => 'jms/Remote/CF',
    }

In this example you are managing a foreign server object in the default domain. When you want to
manage a foreign server object in a specific domain, you can use:

wls_foreign_server_object { 'my_domain/jmsClusterModule:Jboss:JBossQ':
  ensure         => 'present',
  localjndiname  => 'jms/jboss/Queue',
  object_type    => 'destination',
  remotejndiname => 'jms/Remote/Queue',
}

## Attributes



Attribute Name                                                                      | Short Description                                                                                                                             |
----------------------------------------------------------------------------------- | --------------------------------------------------------------------------------------------------------------------------------------------- |
[connection_health_checking](#wls_foreign_server_object_connection_health_checking) | Controls connection health checking for JMS resource reference pools that access this JMS foreign connection factory mapping.                 |
[domain](#wls_foreign_server_object_domain)                                         | With this parameter, you identify the domain, where your objects is in.                                                                       |
[ensure](#wls_foreign_server_object_ensure)                                         | The basic property that the resource should be in.                                                                                            |
[foreign_server](#wls_foreign_server_object_foreign_server)                         | Foreign server name
                                                                                                                          |
[jmsmodule](#wls_foreign_server_object_jmsmodule)                                   | The JMS module name.                                                                                                                          |
[local_jndi_name](#wls_foreign_server_object_local_jndi_name)                       | The name that the remote object will be bound to in the local server's JNDI tree.                                                             |
[localjndiname](#wls_foreign_server_object_localjndiname)                           | The Local JNDI of the Foreign server object
                                                                                                  |
[name](#wls_foreign_server_object_name)                                             | The name.                                                                                                                                     |
[notes](#wls_foreign_server_object_notes)                                           | Optional information that you can include to describe this named JMS descriptor bean.                                                         |
[object_name](#wls_foreign_server_object_object_name)                               | Foreign Server Object name
                                                                                                                   |
[object_type](#wls_foreign_server_object_object_type)                               | The object_type of a Foreign Server object
                                                                                                   |
[password](#wls_foreign_server_object_password)                                     | The password used in conjunction with the user name specified in the <code>Username</code> parameter to access the remote connection factory. |
[provider](#wls_foreign_server_object_provider)                                     | resource.                                                                                                                                     |
[remote_jndi_name](#wls_foreign_server_object_remote_jndi_name)                     | The name of the remote object that will be looked up in the remote JNDI directory.                                                            |
[remotejndiname](#wls_foreign_server_object_remotejndiname)                         | The Remote JNDI of the Foreign server object
                                                                                                 |
[timeout](#wls_foreign_server_object_timeout)                                       | Timeout for applying a resource.                                                                                                              |
[username](#wls_foreign_server_object_username)                                     | The user name that is passed when opening a connection to the remote server (represented by this foreign connection factory).                 |




### connection_health_checking<a name='wls_foreign_server_object_connection_health_checking'>

Controls connection health checking for JMS resource reference pools that access this JMS foreign connection factory mapping. The default value is <code>Enabled</code>. Oracle recommends selecting <code>Disabled</code> only when directed to do so by customer support.

An example on how to use this:

    wls_foreign_server_object {a_wls_foreign_server_object :
       ...
       connection_health_checking => 'enabled'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_foreign_server_object:connection_health_checking']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_foreign_server_object](#attributes)


### domain<a name='wls_foreign_server_object_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.


[Back to overview of wls_foreign_server_object](#attributes)


### ensure<a name='wls_foreign_server_object_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 
[Back to overview of wls_foreign_server_object](#attributes)


### foreign_server<a name='wls_foreign_server_object_foreign_server'>

Foreign server name


[Back to overview of wls_foreign_server_object](#attributes)


### jmsmodule<a name='wls_foreign_server_object_jmsmodule'>

The JMS module name.


[Back to overview of wls_foreign_server_object](#attributes)


### local_jndi_name<a name='wls_foreign_server_object_local_jndi_name'>

The name that the remote object will be bound to in the local server's JNDI tree. This is the name that should be used to look up the object on the local server.

An example on how to use this:

    wls_foreign_server_object {a_wls_foreign_server_object :
       ...
       local_jndi_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_foreign_server_object:local_jndi_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_foreign_server_object](#attributes)


### localjndiname<a name='wls_foreign_server_object_localjndiname'>

The Local JNDI of the Foreign server object


[Back to overview of wls_foreign_server_object](#attributes)


### name<a name='wls_foreign_server_object_name'>

The name.


[Back to overview of wls_foreign_server_object](#attributes)


### notes<a name='wls_foreign_server_object_notes'>

Optional information that you can include to describe this named JMS descriptor bean.  JMS module saves this note in the JMS descriptor file as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  <dl> <dt>Note:</dt>  <dd> If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds. </dd> </dl>

An example on how to use this:

    wls_foreign_server_object {a_wls_foreign_server_object :
       ...
       notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_foreign_server_object:notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_foreign_server_object](#attributes)


### object_name<a name='wls_foreign_server_object_object_name'>

Foreign Server Object name


[Back to overview of wls_foreign_server_object](#attributes)


### object_type<a name='wls_foreign_server_object_object_type'>

The object_type of a Foreign Server object

Valid values are `destination`, `connectionfactory`. 
[Back to overview of wls_foreign_server_object](#attributes)


### password<a name='wls_foreign_server_object_password'>

The password used in conjunction with the user name specified in the <code>Username</code> parameter to access the remote connection factory.

An example on how to use this:

    wls_foreign_server_object {a_wls_foreign_server_object :
       ...
       password => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_foreign_server_object:password']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_foreign_server_object](#attributes)


### provider<a name='wls_foreign_server_object_provider'>

The specific backend to use for this `wls_foreign_server_object`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Foreign Server object in a JMS module of an WebLogic domain via regular WLST


[Back to overview of wls_foreign_server_object](#attributes)


### remote_jndi_name<a name='wls_foreign_server_object_remote_jndi_name'>

The name of the remote object that will be looked up in the remote JNDI directory.

An example on how to use this:

    wls_foreign_server_object {a_wls_foreign_server_object :
       ...
       remote_jndi_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_foreign_server_object:remote_jndi_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_foreign_server_object](#attributes)


### remotejndiname<a name='wls_foreign_server_object_remotejndiname'>

The Remote JNDI of the Foreign server object


[Back to overview of wls_foreign_server_object](#attributes)


### timeout<a name='wls_foreign_server_object_timeout'>

Timeout for applying a resource.

To be sure no Puppet operation, hangs a Puppet daemon, all operations have a timeout. When this timeout
expires, Puppet will abort the current operation and signal an error in the Puppet run.

With this parameter, you can specify the length of the timeout. The value is specified in seconds. In
this example, the `timeout`  is set to `600`  seconds.

    wls_server{'my_server':
      ...
      timeout => 600,
    }

The default value for `timeout` is 120 seconds.


[Back to overview of wls_foreign_server_object](#attributes)


### username<a name='wls_foreign_server_object_username'>

The user name that is passed when opening a connection to the remote server (represented by this foreign connection factory).

An example on how to use this:

    wls_foreign_server_object {a_wls_foreign_server_object :
       ...
       username => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_foreign_server_object:username']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_foreign_server_object](#attributes)

