---
title: wls jms bridge destination
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage a jms bridge destination in an WebLogic domain.

Here is an example on how you should use this:

    wls_jms_bridge_destination { 'myBridgeDest':
      ensure                => 'present',
      adapter               => 'eis.jms.WLSConnectionFactoryJNDINoTX',
      classpath             => 'myClasspath',
      connectionfactoryjndi => 'myCFJndi',
      connectionurl         => 'myConnUrl',
      destinationjndi       => 'myDestJndi',
      destinationtype       => 'Queue',
      initialcontextfactory => 'weblogic.jndi.WLInitialContextFactory',
    }

In this example you are managing a bridge destination in the default domain. When you want to
manage a bridge destination in a specific domain, you can use:

    wls_jms_bridge_destination { 'my_domain/myBridgeDest':
      ensure                => 'present',
      adapter               => 'eis.jms.WLSConnectionFactoryJNDINoTX',
      classpath             => 'myClasspath',
      connectionfactoryjndi => 'myCFJndi',
      connectionurl         => 'myConnUrl',
      destinationjndi       => 'myDestJndi',
      destinationtype       => 'Queue',
      initialcontextfactory => 'weblogic.jndi.WLInitialContextFactory',
    }

[Here](https://javamail.java.net/nonav/docs/api/) you can find more information about JMS bridge
desitinations.

## Attributes



Attribute Name                                                                           | Short Description                                                                |
---------------------------------------------------------------------------------------- | -------------------------------------------------------------------------------- |
[adapter](#wls_jms_bridge_destination_adapter)                                           | The JNDI name of the adapter used to communicate with the specified destination. |
[adapter_jndi_name](#wls_jms_bridge_destination_adapter_jndi_name)                       | The JNDI name of the adapter used to communicate with the specified destination. |
[bridge_destination_name](#wls_jms_bridge_destination_bridge_destination_name)           | The bridge destination name
                                                     |
[classpath](#wls_jms_bridge_destination_classpath)                                       | The classpath for this bridge destination.                                       |
[connection_factory_jndi_name](#wls_jms_bridge_destination_connection_factory_jndi_name) | The connection factory's JNDI name for this JMS bridge destination.              |
[connection_url](#wls_jms_bridge_destination_connection_url)                             | The connection URL for this JMS bridge destination.                              |
[connectionfactoryjndi](#wls_jms_bridge_destination_connectionfactoryjndi)               | The connection factory's JNDI name for this JMS bridge destination.              |
[connectionurl](#wls_jms_bridge_destination_connectionurl)                               | The connectionurl.                                                               |
[destination_jndi_name](#wls_jms_bridge_destination_destination_jndi_name)               | The destination JNDI name for this JMS bridge destination.                       |
[destination_type](#wls_jms_bridge_destination_destination_type)                         | The destination type (queue or topic) for this JMS bridge destination.           |
[destinationjndi](#wls_jms_bridge_destination_destinationjndi)                           | The destination JNDI name for this JMS bridge destination.                       |
[destinationtype](#wls_jms_bridge_destination_destinationtype)                           | The destination type (queue or topic) for this JMS bridge destination.           |
[domain](#wls_jms_bridge_destination_domain)                                             | With this parameter, you identify the domain, where your objects is in.          |
[ensure](#wls_jms_bridge_destination_ensure)                                             | The basic property that the resource should be in.                               |
[initial_context_factory](#wls_jms_bridge_destination_initial_context_factory)           | The initial context factory name for this JMS bridge destination.                |
[initialcontextfactory](#wls_jms_bridge_destination_initialcontextfactory)               | The initial contextfactory.                                                      |
[name](#wls_jms_bridge_destination_name)                                                 | The name.                                                                        |
[notes](#wls_jms_bridge_destination_notes)                                               | Optional information that you can include to describe this configuration.        |
[password](#wls_jms_bridge_destination_password)                                         | The bridge password.                                                             |
[provider](#wls_jms_bridge_destination_provider)                                         | resource.                                                                        |
[tags](#wls_jms_bridge_destination_tags)                                                 | Return all tags on this Configuration MBean
                                     |
[user_name](#wls_jms_bridge_destination_user_name)                                       | The user name.                                                                   |
[user_password](#wls_jms_bridge_destination_user_password)                               | The user password that the adapter uses to access the bridge destination.        |




### adapter<a name='wls_jms_bridge_destination_adapter'>

The JNDI name of the adapter used to communicate with the specified destination.

Valid values are `eis.jms.WLSConnectionFactoryJNDINoTX`, `eis.jms.WLSConnectionFactoryJNDIXA`. 
[Back to overview of wls_jms_bridge_destination](#attributes)


### adapter_jndi_name<a name='wls_jms_bridge_destination_adapter_jndi_name'>

The JNDI name of the adapter used to communicate with the specified destination.  This name is specified in the adapter's deployment descriptor file and is used by the WebLogic Server Connector container to bind the adapter in WebLogic Server JNDI.

An example on how to use this:

    wls_jms_bridge_destination {a_wls_jms_bridge_destination :
       ...
       adapter_jndi_name => 'eis.jms.WLSConnectionFactoryJNDIXA'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_bridge_destination:adapter_jndi_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_bridge_destination](#attributes)


### bridge_destination_name<a name='wls_jms_bridge_destination_bridge_destination_name'>

The bridge destination name


[Back to overview of wls_jms_bridge_destination](#attributes)


### classpath<a name='wls_jms_bridge_destination_classpath'>

The classpath for this bridge destination.


[Back to overview of wls_jms_bridge_destination](#attributes)


### connection_factory_jndi_name<a name='wls_jms_bridge_destination_connection_factory_jndi_name'>

The connection factory's JNDI name for this JMS bridge destination.

An example on how to use this:

    wls_jms_bridge_destination {a_wls_jms_bridge_destination :
       ...
       connection_factory_jndi_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_bridge_destination:connection_factory_jndi_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_bridge_destination](#attributes)


### connection_url<a name='wls_jms_bridge_destination_connection_url'>

The connection URL for this JMS bridge destination.

An example on how to use this:

    wls_jms_bridge_destination {a_wls_jms_bridge_destination :
       ...
       connection_url => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_bridge_destination:connection_url']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_bridge_destination](#attributes)


### connectionfactoryjndi<a name='wls_jms_bridge_destination_connectionfactoryjndi'>

The connection factory's JNDI name for this JMS bridge destination.


[Back to overview of wls_jms_bridge_destination](#attributes)


### connectionurl<a name='wls_jms_bridge_destination_connectionurl'>

The connectionurl.


[Back to overview of wls_jms_bridge_destination](#attributes)


### destination_jndi_name<a name='wls_jms_bridge_destination_destination_jndi_name'>

The destination JNDI name for this JMS bridge destination.

An example on how to use this:

    wls_jms_bridge_destination {a_wls_jms_bridge_destination :
       ...
       destination_jndi_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_bridge_destination:destination_jndi_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_bridge_destination](#attributes)


### destination_type<a name='wls_jms_bridge_destination_destination_type'>

The destination type (queue or topic) for this JMS bridge destination.

An example on how to use this:

    wls_jms_bridge_destination {a_wls_jms_bridge_destination :
       ...
       destination_type => 'Queue'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_bridge_destination:destination_type']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_bridge_destination](#attributes)


### destinationjndi<a name='wls_jms_bridge_destination_destinationjndi'>

The destination JNDI name for this JMS bridge destination.


[Back to overview of wls_jms_bridge_destination](#attributes)


### destinationtype<a name='wls_jms_bridge_destination_destinationtype'>

The destination type (queue or topic) for this JMS bridge destination.

Valid values are `Queue`, `Topic`. 
[Back to overview of wls_jms_bridge_destination](#attributes)


### domain<a name='wls_jms_bridge_destination_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.


[Back to overview of wls_jms_bridge_destination](#attributes)


### ensure<a name='wls_jms_bridge_destination_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 
[Back to overview of wls_jms_bridge_destination](#attributes)


### initial_context_factory<a name='wls_jms_bridge_destination_initial_context_factory'>

The initial context factory name for this JMS bridge destination.

An example on how to use this:

    wls_jms_bridge_destination {a_wls_jms_bridge_destination :
       ...
       initial_context_factory => 'weblogic.jndi.WLInitialContextFactory'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_bridge_destination:initial_context_factory']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_bridge_destination](#attributes)


### initialcontextfactory<a name='wls_jms_bridge_destination_initialcontextfactory'>

The initial contextfactory.


[Back to overview of wls_jms_bridge_destination](#attributes)


### name<a name='wls_jms_bridge_destination_name'>

The name.


[Back to overview of wls_jms_bridge_destination](#attributes)


### notes<a name='wls_jms_bridge_destination_notes'>

Optional information that you can include to describe this configuration.  WebLogic Server saves this note in the domain's configuration file (<code>config.xml</code>) as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  <dl> <dt>Note:</dt>  <dd> If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds. </dd> </dl>

An example on how to use this:

    wls_jms_bridge_destination {a_wls_jms_bridge_destination :
       ...
       notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_bridge_destination:notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_bridge_destination](#attributes)


### password<a name='wls_jms_bridge_destination_password'>

The bridge password.

Usage :

    wls_jms_bridge_destination { ....:
      ...
      password => 'clear_text_password',
      ...
    }

The password string is passed to WebLogic for encryption and then stored in the domain.


[Back to overview of wls_jms_bridge_destination](#attributes)


### provider<a name='wls_jms_bridge_destination_provider'>

The specific backend to use for this `wls_jms_bridge_destination`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage a JMS bridge destinaion in an WebLogic domain via regular WLST


[Back to overview of wls_jms_bridge_destination](#attributes)


### tags<a name='wls_jms_bridge_destination_tags'>

Return all tags on this Configuration MBean

An example on how to use this:

    wls_jms_bridge_destination {a_wls_jms_bridge_destination :
       ...
       tags => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_bridge_destination:tags']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_bridge_destination](#attributes)


### user_name<a name='wls_jms_bridge_destination_user_name'>

The user name.


[Back to overview of wls_jms_bridge_destination](#attributes)


### user_password<a name='wls_jms_bridge_destination_user_password'>

The user password that the adapter uses to access the bridge destination.  As of 8.1 sp4, when you get the value of this attribute, WebLogic Server does the following: <ol><li>Retrieves the value of the <code>UserPasswordEncrypted</code> attribute. <li>Decrypts the value and returns the unencrypted password as a String. </ol>  When you set the value of this attribute, WebLogic Server does the following: <ol><li>Encrypts the value.</li> <li>Sets the value of the <code>UserPasswordEncrypted</code> attribute to the encrypted value.</li> </ol> Using this attribute (<code>UserPassword</code>) is a potential security risk because the String object (which contains the unencrypted password) remains in the JVM's memory until garbage collection removes it and the memory is reallocated. Depending on how memory is allocated in the JVM, a significant amount of time could pass before this unencrypted data is removed from memory.  Instead of using this attribute, use <code>UserPasswordEncrypted</code>.

An example on how to use this:

    wls_jms_bridge_destination {a_wls_jms_bridge_destination :
       ...
       user_password => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_bridge_destination:user_password']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_bridge_destination](#attributes)

