---
title: wls jms module
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage a JMS module in an WebLogic domain.

Here is an example on how you should use this:

    wls_jms_module { 'jmsClusterModule':
      ensure     => 'present',
      target     => ['WebCluster'],
      targettype => ['Cluster'],
    }

In this example you are managing a JMS module in the default domain. When you want to
manage a JMS module in a specific domain, you can use:

    wls_jms_module { 'my_domain/jmsClusterModule':
      ensure     => 'present',
      target     => ['WebCluster'],
      targettype => ['Cluster'],
    }

## Attributes



Attribute Name                                                         | Short Description                                                                                                                           |
---------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------------------- |
[compatibility_name](#wls_jms_module_compatibility_name)               |  This is only set for beans created as a result of conversion from an 8.1 application configured using ApplicationMBean and ComponentMBean. |
[deployment_order](#wls_jms_module_deployment_order)                   | An integer value that indicates when this unit is deployed, relative to other deployable units on a server, during startup.                 |
[deployment_principal_name](#wls_jms_module_deployment_principal_name) | A string value that indicates the principal that should be used when deploying the file or archive during startup and shutdown.             |
[domain](#wls_jms_module_domain)                                       | With this parameter, you identify the domain, where your objects is in.                                                                     |
[ensure](#wls_jms_module_ensure)                                       | The basic property that the resource should be in.                                                                                          |
[jms_module_name](#wls_jms_module_jms_module_name)                     | The jms module name
                                                                                                                        |
[module_type](#wls_jms_module_module_type)                             | The values match those defined by jsr88.                                                                                                    |
[name](#wls_jms_module_name)                                           | The name.                                                                                                                                   |
[notes](#wls_jms_module_notes)                                         | Optional information that you can include to describe this configuration.                                                                   |
[policyexpression](#wls_jms_module_policyexpression)                   | A string representation of an security authorization policy
                                                                                |
[provider](#wls_jms_module_provider)                                   | resource.                                                                                                                                   |
[source_path](#wls_jms_module_source_path)                             | 
                                                                                                                                           |
[tags](#wls_jms_module_tags)                                           | Return all tags on this Configuration MBean
                                                                                                |
[target](#wls_jms_module_target)                                       | An array of target names.                                                                                                                   |
[targettype](#wls_jms_module_targettype)                               | An array of target types.                                                                                                                   |
[timeout](#wls_jms_module_timeout)                                     | Timeout for applying a resource.                                                                                                            |




### compatibility_name<a name='wls_jms_module_compatibility_name'>

 This is only set for beans created as a result of conversion from an 8.1 application configured using ApplicationMBean and ComponentMBean.  Standalone modules in 8.1 have both an ApplicationMBean name and ComponentMBean name. This attribute stores the name of the latter, to be used when the server creates the transient ComponentMBean for backward compatibility.

An example on how to use this:

    wls_jms_module {a_wls_jms_module :
       ...
       compatibility_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_module:compatibility_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_module](#attributes)


### deployment_order<a name='wls_jms_module_deployment_order'>

An integer value that indicates when this unit is deployed, relative to other deployable units on a server, during startup.  Units with lower values are deployed before those with higher values.

An example on how to use this:

    wls_jms_module {a_wls_jms_module :
       ...
       deployment_order => '100'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_module:deployment_order']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_module](#attributes)


### deployment_principal_name<a name='wls_jms_module_deployment_principal_name'>

A string value that indicates the principal that should be used when deploying the file or archive during startup and shutdown. This principal will be used to set the current subject when calling out into application code for interfaces such as ApplicationLifecycleListener. If no principal name is specified, then the anonymous principal will be used.

An example on how to use this:

    wls_jms_module {a_wls_jms_module :
       ...
       deployment_principal_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_module:deployment_principal_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_module](#attributes)


### domain<a name='wls_jms_module_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.


[Back to overview of wls_jms_module](#attributes)


### ensure<a name='wls_jms_module_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 
[Back to overview of wls_jms_module](#attributes)


### jms_module_name<a name='wls_jms_module_jms_module_name'>

The jms module name


[Back to overview of wls_jms_module](#attributes)


### module_type<a name='wls_jms_module_module_type'>

The values match those defined by jsr88. This attribute may move to another MBean.

An example on how to use this:

    wls_jms_module {a_wls_jms_module :
       ...
       module_type => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_module:module_type']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_module](#attributes)


### name<a name='wls_jms_module_name'>

The name.


[Back to overview of wls_jms_module](#attributes)


### notes<a name='wls_jms_module_notes'>

Optional information that you can include to describe this configuration.  WebLogic Server saves this note in the domain's configuration file (<code>config.xml</code>) as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  <dl> <dt>Note:</dt>  <dd> If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds. </dd> </dl>

An example on how to use this:

    wls_jms_module {a_wls_jms_module :
       ...
       notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_module:notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_module](#attributes)


### policyexpression<a name='wls_jms_module_policyexpression'>

A string representation of an security authorization policy


[Back to overview of wls_jms_module](#attributes)


### provider<a name='wls_jms_module_provider'>

The specific backend to use for this `wls_jms_module`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage a JMS module in an WebLogic domain via regular WLST


[Back to overview of wls_jms_module](#attributes)


### source_path<a name='wls_jms_module_source_path'>



An example on how to use this:

    wls_jms_module {a_wls_jms_module :
       ...
       source_path => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_module:source_path']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_module](#attributes)


### tags<a name='wls_jms_module_tags'>

Return all tags on this Configuration MBean

An example on how to use this:

    wls_jms_module {a_wls_jms_module :
       ...
       tags => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_module:tags']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_module](#attributes)


### target<a name='wls_jms_module_target'>

An array of target names.

The array of targets for this resource. A target can be a WebLogic Server, a WebLogic cluster, or a JMS Server.
When specifying a `target`, you'll also have to specify `targettype`. Here is an example on how you can specify a `target`.

    ..{ 'aResource':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }

here is an example on specifying the `target` and `targettype` for a regular WebLogic cluster:

    wls_cluster{ 'aCluster':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }


[Back to overview of wls_jms_module](#attributes)


### targettype<a name='wls_jms_module_targettype'>

An array of target types.

The array of target types for this resource. A target can be a WebLogic Server, a WebLogic cluster, or a JMS Server.
When specifying a `targettype`, you'll also have to specify a `target`. Here is an example on how you can specify a `target`.

    ...{ 'aResource':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }

here is an example on specifying the `target` and `targettype` for a regular WebLogic cluster:

    wls_cluster{ 'aCluster':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }


[Back to overview of wls_jms_module](#attributes)


### timeout<a name='wls_jms_module_timeout'>

Timeout for applying a resource.

To be sure no Puppet operation, hangs a Puppet daemon, all operations have a timeout. When this timeout
expires, Puppet will abort the current operation and signal an error in the Puppet run.

With this parameter, you can specify the length of the timeout. The value is specified in seconds. In
this example, the `timeout`  is set to `600`  seconds.

    wls_server{'my_server':
      ...
      timeout => 600,
    }

The default value for `timeout` is 120 seconds.


[Back to overview of wls_jms_module](#attributes)

