---
title: wls jms quota
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage a Quota in a JMS module of a WebLogic domain.

Here is an example on how you should use this:

    wls_jms_quota { 'jmsClusterModule:QuotaBig':
      ensure          => 'present',
      bytesmaximum    => '9223372036854775807',
      messagesmaximum => '9223372036854775807',
      policy          => 'FIFO',
      shared          => '1',
    }

In this example you are managing a JMS quota in the default domain. When you want to
manage a JMS quota in a specific domain, you can use:

    wls_jms_quota { 'my_domain/jmsClusterModule:QuotaLow':
      ensure          => 'present',
      bytesmaximum    => '20000000000',
      messagesmaximum => '9223372036854775807',
      policy          => 'FIFO',
      shared          => '0',
    }

## Attributes



Attribute Name                                      | Short Description                                                                      |
--------------------------------------------------- | -------------------------------------------------------------------------------------- |
[bytes_maximum](#wls_jms_quota_bytes_maximum)       | The total number of bytes that can be stored in a destination that uses this quota.    |
[bytesmaximum](#wls_jms_quota_bytesmaximum)         | Quota Bytes Maximum
                                                                   |
[domain](#wls_jms_quota_domain)                     | With this parameter, you identify the domain, where your objects is in.                |
[ensure](#wls_jms_quota_ensure)                     | The basic property that the resource should be in.                                     |
[jmsmodule](#wls_jms_quota_jmsmodule)               | The JMS module name.                                                                   |
[messages_maximum](#wls_jms_quota_messages_maximum) | The total number of messages that can be stored in a destination that uses this quota. |
[messagesmaximum](#wls_jms_quota_messagesmaximum)   | Maximum messages
                                                                      |
[name](#wls_jms_quota_name)                         | The name.                                                                              |
[notes](#wls_jms_quota_notes)                       | Optional information that you can include to describe this named JMS descriptor bean.  |
[policy](#wls_jms_quota_policy)                     | policy name of the Quota
                                                              |
[provider](#wls_jms_quota_provider)                 | resource.                                                                              |
[quota_name](#wls_jms_quota_quota_name)             | The quota name
                                                                        |
[shared](#wls_jms_quota_shared)                     | Shared Quota
                                                                          |
[timeout](#wls_jms_quota_timeout)                   | Timeout for applying a resource.                                                       |




### bytes_maximum<a name='wls_jms_quota_bytes_maximum'>

The total number of bytes that can be stored in a destination that uses this quota.  A value of zero means that no messages can be placed on a destination without exceeding the quota. A value of -1 prevents WebLogic Server from imposing a limit.  Because excessive bytes volume can cause memory saturation, Oracle recommends that the maximum corresponds to the amount of system memory that is available after accounting for the rest of your application load.  No consideration is given to messages that are pending; that is, messages that are in-flight, delayed, or otherwise inhibited from delivery still count against the message and/or bytes quota.</p.  This attribute is dynamic and can be changed at any time. If the quota is lowered and the quota object is now over quota, then subsequent requests for quota will be denied until quota is available. If the quota is raised, then this may allow the quota object to satisfy existing requests for quota.  Note: If a JMS template is used for distributed destination members, then this maximum applies only to those specific members and not the distributed destination set as a whole.

An example on how to use this:

    wls_jms_quota {a_wls_jms_quota :
       ...
       bytes_maximum => '9223372036854775807'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_quota:bytes_maximum']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_quota](#attributes)


### bytesmaximum<a name='wls_jms_quota_bytesmaximum'>

Quota Bytes Maximum


[Back to overview of wls_jms_quota](#attributes)


### domain<a name='wls_jms_quota_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.


[Back to overview of wls_jms_quota](#attributes)


### ensure<a name='wls_jms_quota_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 
[Back to overview of wls_jms_quota](#attributes)


### jmsmodule<a name='wls_jms_quota_jmsmodule'>

The JMS module name.


[Back to overview of wls_jms_quota](#attributes)


### messages_maximum<a name='wls_jms_quota_messages_maximum'>

The total number of messages that can be stored in a destination that uses this quota.  A value of zero means that no messages can be placed on a destination without exceeding the quota. A value of -1 prevents WebLogic Server from imposing a limit.  Because excessive bytes volume can cause memory saturation, Oracle recommends that the maximum corresponds to the amount of system memory that is available after accounting for the rest of your application load.  No consideration is given to messages that are pending; that is, messages that are in-flight, delayed, or otherwise inhibited from delivery still count against the message and/or bytes quota.</p.  This attribute is dynamic and can be changed at any time. If the quota is lowered and the quota object is now over quota, then subsequent requests for quota will be denied until quota is available. If the quota is raised, then this may allow the quota object to satisfy existing requests for quota.  Note: If a JMS template is used for distributed destination members, then this maximum applies only to those specific members and not the distributed destination set as a whole.

An example on how to use this:

    wls_jms_quota {a_wls_jms_quota :
       ...
       messages_maximum => '9223372036854775807'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_quota:messages_maximum']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_quota](#attributes)


### messagesmaximum<a name='wls_jms_quota_messagesmaximum'>

Maximum messages


[Back to overview of wls_jms_quota](#attributes)


### name<a name='wls_jms_quota_name'>

The name.


[Back to overview of wls_jms_quota](#attributes)


### notes<a name='wls_jms_quota_notes'>

Optional information that you can include to describe this named JMS descriptor bean.  JMS module saves this note in the JMS descriptor file as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  <dl> <dt>Note:</dt>  <dd> If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds. </dd> </dl>

An example on how to use this:

    wls_jms_quota {a_wls_jms_quota :
       ...
       notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_quota:notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_jms_quota](#attributes)


### policy<a name='wls_jms_quota_policy'>

policy name of the Quota

Valid values are `absent`, `FIFO`, `Preemptive`. 
[Back to overview of wls_jms_quota](#attributes)


### provider<a name='wls_jms_quota_provider'>

The specific backend to use for this `wls_jms_quota`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage quotas of a JMS module in an WebLogic domain via regular WLST


[Back to overview of wls_jms_quota](#attributes)


### quota_name<a name='wls_jms_quota_quota_name'>

The quota name


[Back to overview of wls_jms_quota](#attributes)


### shared<a name='wls_jms_quota_shared'>

Shared Quota

Valid values are `absent`, `1`, `0`. 
[Back to overview of wls_jms_quota](#attributes)


### timeout<a name='wls_jms_quota_timeout'>

Timeout for applying a resource.

To be sure no Puppet operation, hangs a Puppet daemon, all operations have a timeout. When this timeout
expires, Puppet will abort the current operation and signal an error in the Puppet run.

With this parameter, you can specify the length of the timeout. The value is specified in seconds. In
this example, the `timeout`  is set to `600`  seconds.

    wls_server{'my_server':
      ...
      timeout => 600,
    }

The default value for `timeout` is 120 seconds.


[Back to overview of wls_jms_quota](#attributes)

