---
title: wls saf imported destination object
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage a SAF imported destinations object in a JMS Module of a WebLogic domain.

Here is an example on how you should use this:

    wls_saf_imported_destination_object { 'jmsClusterModule:SAFImportedDestinations-0:SAFDemoQueue':
      ensure               => 'present',
      nonpersistentqos     => 'Exactly-Once',
      object_type          => 'queue',
      remotejndiname       => 'jms/DemoQueue',
      unitoforderrouting   => 'Hash',
      usetimetolivedefault => '0',
    }

In this example you are managing a SAF imported destination object in the default domain. When you want to
manage a SAF imported destination object in a specific domain, you can use:

    wls_saf_imported_destination_object { 'my_domain/jmsClusterModule:SAFImportedDestinations-0:SAFDemoTopic':
      ensure               => 'present',
      nonpersistentqos     => 'Exactly-Once',
      object_type          => 'topic',
      remotejndiname       => 'jms/DemoTopic',
      timetolivedefault    => '100000000',
      unitoforderrouting   => 'Hash',
      usetimetolivedefault => '1',
    }

## Attributes



Attribute Name                                                                                    | Short Description                                                                                                                                                                    |
------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------ |
[domain](#wls_saf_imported_destination_object_domain)                                             | With this parameter, you identify the domain, where your objects is in.                                                                                                              |
[ensure](#wls_saf_imported_destination_object_ensure)                                             | The basic property that the resource should be in.                                                                                                                                   |
[imported_destination](#wls_saf_imported_destination_object_imported_destination)                 | SAF imported destination name
                                                                                                                                                       |
[jmsmodule](#wls_saf_imported_destination_object_jmsmodule)                                       | The JMS module name.                                                                                                                                                                 |
[local_jndi_name](#wls_saf_imported_destination_object_local_jndi_name)                           | The local JNDI name of the remote destination.                                                                                                                                       |
[localjndiname](#wls_saf_imported_destination_object_localjndiname)                               | The Local JNDI of the SAF imported destination object
                                                                                                                               |
[log_message_logging_enabled](#wls_saf_imported_destination_object_log_message_logging_enabled)   | Specifies whether the module logs information about the message life cycle.                                                                                                          |
[log_message_logging_format](#wls_saf_imported_destination_object_log_message_logging_format)     | Defines which information about the message is logged.                                                                                                                               |
[log_template_bean](#wls_saf_imported_destination_object_log_template_bean)                       | Finds the template bean for this destination.                                                                                                                                        |
[name](#wls_saf_imported_destination_object_name)                                                 | The name.                                                                                                                                                                            |
[non_persistent_qos](#wls_saf_imported_destination_object_non_persistent_qos)                     | Specifies the quality-of-service for non-persistent messages.                                                                                                                        |
[nonpersistentqos](#wls_saf_imported_destination_object_nonpersistentqos)                         | The QoS non persistent of the SAF imported destination object
                                                                                                                       |
[notes](#wls_saf_imported_destination_object_notes)                                               | Optional information that you can include to describe this named JMS descriptor bean.                                                                                                |
[object_name](#wls_saf_imported_destination_object_object_name)                                   | SAF imported destination Object name
                                                                                                                                                |
[object_type](#wls_saf_imported_destination_object_object_type)                                   | The object_type of the SAF imported destination object
                                                                                                                              |
[persistent_qos](#wls_saf_imported_destination_object_persistent_qos)                             | Specifies the quality-of-service for persistent messages.                                                                                                                            |
[provider](#wls_saf_imported_destination_object_provider)                                         | resource.                                                                                                                                                                            |
[remote_jndi_name](#wls_saf_imported_destination_object_remote_jndi_name)                         | The remote JNDI name of the remote destination.                                                                                                                                      |
[remotejndiname](#wls_saf_imported_destination_object_remotejndiname)                             | The Remote JNDI of the SAF imported destination object
                                                                                                                              |
[saf_error_handling](#wls_saf_imported_destination_object_saf_error_handling)                     | Specifies the error handling configuration used by this SAF destination.                                                                                                             |
[time_to_live_default](#wls_saf_imported_destination_object_time_to_live_default)                 | Specifies the default Time-to-Live value (expiration time), in milliseconds, for imported JMS messages.                                                                              |
[timeout](#wls_saf_imported_destination_object_timeout)                                           | Timeout for applying a resource.                                                                                                                                                     |
[timetolivedefault](#wls_saf_imported_destination_object_timetolivedefault)                       | the SAF time to live default of this SAF imported destination
                                                                                                                       |
[unit_of_order_routing](#wls_saf_imported_destination_object_unit_of_order_routing)               | Specifies the type of routing used to find a SAF agent when using the message Unit-of-Order feature.                                                                                 |
[unitoforderrouting](#wls_saf_imported_destination_object_unitoforderrouting)                     | The unit of order routing of the SAF imported destination object
                                                                                                                    |
[use_saf_time_to_live_default](#wls_saf_imported_destination_object_use_saf_time_to_live_default) | Controls whether the Time-to-Live (expiration time) value set on imported JMS messages will be overridden by the value specified in the <code>SAF Default Time-to-Live</code> field. |
[usetimetolivedefault](#wls_saf_imported_destination_object_usetimetolivedefault)                 | use time to live default of this SAF imported destination
                                                                                                                           |




### domain<a name='wls_saf_imported_destination_object_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.


[Back to overview of wls_saf_imported_destination_object](#attributes)


### ensure<a name='wls_saf_imported_destination_object_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 
[Back to overview of wls_saf_imported_destination_object](#attributes)


### imported_destination<a name='wls_saf_imported_destination_object_imported_destination'>

SAF imported destination name


[Back to overview of wls_saf_imported_destination_object](#attributes)


### jmsmodule<a name='wls_saf_imported_destination_object_jmsmodule'>

The JMS module name.


[Back to overview of wls_saf_imported_destination_object](#attributes)


### local_jndi_name<a name='wls_saf_imported_destination_object_local_jndi_name'>

The local JNDI name of the remote destination.

An example on how to use this:

    wls_saf_imported_destination_object {a_wls_saf_imported_destination_object :
       ...
       local_jndi_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_saf_imported_destination_object:local_jndi_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_saf_imported_destination_object](#attributes)


### localjndiname<a name='wls_saf_imported_destination_object_localjndiname'>

The Local JNDI of the SAF imported destination object


[Back to overview of wls_saf_imported_destination_object](#attributes)


### log_message_logging_enabled<a name='wls_saf_imported_destination_object_log_message_logging_enabled'>

Specifies whether the module logs information about the message life cycle.

An example on how to use this:

    wls_saf_imported_destination_object {a_wls_saf_imported_destination_object :
       ...
       log_message_logging_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_saf_imported_destination_object:log_message_logging_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_saf_imported_destination_object](#attributes)


### log_message_logging_format<a name='wls_saf_imported_destination_object_log_message_logging_format'>

Defines which information about the message is logged. Valid values are: <ul> <li> %header% - All JMS header fields are logged. <li> %properties% - All user-defined properties are logged. <li> JMSDeliveryTime - This WebLogic JMS-specific extended header field is logged. <li> JMSRedeliveryLimit - This WebLogic JMS-specific extended header field is logged. <li> foo  - Any valid JMS header field or user-defined property is logged. </ul>   When specifying multiple values, enter them as a comma-separated list. The <tt>%header%</tt> and <tt>%properies% </tt> values are not case sensitive. For example, you could use <tt>"%header%,%properties%"</tt> for all the JMS header fields and user properties. However, the enumeration of individual JMS header fields and user-defined properties are case sensitive. To enumerate only individual JMS header fields you could use <tt>"%header, name, address, city, state, zip"</tt> .   Note: The <tt>JMSMessageID</tt> field is always logged and cannot be turned off. Therefore, if the Message Logging Format is not defined (i.e., null) or is defined as an empty string, then the output to the log file contains only the <tt>JMSMessageID</tt> of the message. Gets the "message-logging-format" element

An example on how to use this:

    wls_saf_imported_destination_object {a_wls_saf_imported_destination_object :
       ...
       log_message_logging_format => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_saf_imported_destination_object:log_message_logging_format']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_saf_imported_destination_object](#attributes)


### log_template_bean<a name='wls_saf_imported_destination_object_log_template_bean'>

Finds the template bean for this destination.

An example on how to use this:

    wls_saf_imported_destination_object {a_wls_saf_imported_destination_object :
       ...
       log_template_bean => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_saf_imported_destination_object:log_template_bean']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_saf_imported_destination_object](#attributes)


### name<a name='wls_saf_imported_destination_object_name'>

The name.


[Back to overview of wls_saf_imported_destination_object](#attributes)


### non_persistent_qos<a name='wls_saf_imported_destination_object_non_persistent_qos'>

Specifies the quality-of-service for non-persistent messages. <ul> <li> <code>Exactly-Once</code> indicates that messages will be forwarded to the remote side once and only once except for any occurrence of server crashes. </li> <li> <code>At-Least-Once</code> indicates that messages will be forwarded to the remote side at least once. No message will be lost except for any occurrence of server crashes. However, messages may appear in the remote endpoint more than once. </li> <li> <code>At-Most-Once</code> indicates that messages will be forwarded to the remote side atmost once. No message will appear in the remote endpoint more than once. However, messages may get lost. </li> </ul> Any change to this parameter affects only incoming messages; stored messages are not affected.

An example on how to use this:

    wls_saf_imported_destination_object {a_wls_saf_imported_destination_object :
       ...
       non_persistent_qos => 'At-Least-Once'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_saf_imported_destination_object:non_persistent_qos']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_saf_imported_destination_object](#attributes)


### nonpersistentqos<a name='wls_saf_imported_destination_object_nonpersistentqos'>

The QoS non persistent of the SAF imported destination object

Valid values are `absent`, `Exactly-Once`, `At-Least-Once`, `At-Most-Once`. 
[Back to overview of wls_saf_imported_destination_object](#attributes)


### notes<a name='wls_saf_imported_destination_object_notes'>

Optional information that you can include to describe this named JMS descriptor bean.  JMS module saves this note in the JMS descriptor file as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  <dl> <dt>Note:</dt>  <dd> If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds. </dd> </dl>

An example on how to use this:

    wls_saf_imported_destination_object {a_wls_saf_imported_destination_object :
       ...
       notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_saf_imported_destination_object:notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_saf_imported_destination_object](#attributes)


### object_name<a name='wls_saf_imported_destination_object_object_name'>

SAF imported destination Object name


[Back to overview of wls_saf_imported_destination_object](#attributes)


### object_type<a name='wls_saf_imported_destination_object_object_type'>

The object_type of the SAF imported destination object

Valid values are `queue`, `topic`. 
[Back to overview of wls_saf_imported_destination_object](#attributes)


### persistent_qos<a name='wls_saf_imported_destination_object_persistent_qos'>

Specifies the quality-of-service for persistent messages. <ul> <li> <code>Exactly-Once</code> indicates that messages will be forwarded to the remote side once and only once </li> <li> <code>At-Least-Once</code> indicates that messages will be forwarded to the remote side at least once. Messages may appear in the remote endpoint more than once. </li> <li> <code>At-Most-Once</code> indicates that messages will be forwarded to the remote side atmost once. No message will appear in the remote endpoint more than once. However, messages may get lost. </li> </ul> Any change to this parameter affects only incoming messages; stored messages are not affected.

An example on how to use this:

    wls_saf_imported_destination_object {a_wls_saf_imported_destination_object :
       ...
       persistent_qos => 'Exactly-Once'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_saf_imported_destination_object:persistent_qos']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_saf_imported_destination_object](#attributes)


### provider<a name='wls_saf_imported_destination_object_provider'>

The specific backend to use for this `wls_saf_imported_destination_object`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: saf imported destination Queue or Topic in a JMS module of an WebLogic domain via regular WLST


[Back to overview of wls_saf_imported_destination_object](#attributes)


### remote_jndi_name<a name='wls_saf_imported_destination_object_remote_jndi_name'>

The remote JNDI name of the remote destination.

An example on how to use this:

    wls_saf_imported_destination_object {a_wls_saf_imported_destination_object :
       ...
       remote_jndi_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_saf_imported_destination_object:remote_jndi_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_saf_imported_destination_object](#attributes)


### remotejndiname<a name='wls_saf_imported_destination_object_remotejndiname'>

The Remote JNDI of the SAF imported destination object


[Back to overview of wls_saf_imported_destination_object](#attributes)


### saf_error_handling<a name='wls_saf_imported_destination_object_saf_error_handling'>

Specifies the error handling configuration used by this SAF destination.  Any change to this parameter affects only incoming messages; stored messages are not affected.

An example on how to use this:

    wls_saf_imported_destination_object {a_wls_saf_imported_destination_object :
       ...
       saf_error_handling => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_saf_imported_destination_object:saf_error_handling']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_saf_imported_destination_object](#attributes)


### time_to_live_default<a name='wls_saf_imported_destination_object_time_to_live_default'>

Specifies the default Time-to-Live value (expiration time), in milliseconds, for imported JMS messages. The expiration time set on JMS messages will override this value unless the <code>SAF Default Time-to-Live Enabled</code> field is switched on, which then overrides the expiration time in JMS messages on imported destinations.  Any change to this value affects only incoming messages; stored messages are not affected.

An example on how to use this:

    wls_saf_imported_destination_object {a_wls_saf_imported_destination_object :
       ...
       time_to_live_default => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_saf_imported_destination_object:time_to_live_default']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_saf_imported_destination_object](#attributes)


### timeout<a name='wls_saf_imported_destination_object_timeout'>

Timeout for applying a resource.

To be sure no Puppet operation, hangs a Puppet daemon, all operations have a timeout. When this timeout
expires, Puppet will abort the current operation and signal an error in the Puppet run.

With this parameter, you can specify the length of the timeout. The value is specified in seconds. In
this example, the `timeout`  is set to `600`  seconds.

    wls_server{'my_server':
      ...
      timeout => 600,
    }

The default value for `timeout` is 120 seconds.


[Back to overview of wls_saf_imported_destination_object](#attributes)


### timetolivedefault<a name='wls_saf_imported_destination_object_timetolivedefault'>

the SAF time to live default of this SAF imported destination


[Back to overview of wls_saf_imported_destination_object](#attributes)


### unit_of_order_routing<a name='wls_saf_imported_destination_object_unit_of_order_routing'>

Specifies the type of routing used to find a SAF agent when using the message Unit-of-Order feature.  <ul> <li><code>Hash</code> indicates that producers use the hash code of a message Unit-of-Order to find a SAF agent. </li>  <li><code>PathService</code> indicates that producers use the Path Service to find a SAF agent. </li> </ul>

An example on how to use this:

    wls_saf_imported_destination_object {a_wls_saf_imported_destination_object :
       ...
       unit_of_order_routing => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_saf_imported_destination_object:unit_of_order_routing']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_saf_imported_destination_object](#attributes)


### unitoforderrouting<a name='wls_saf_imported_destination_object_unitoforderrouting'>

The unit of order routing of the SAF imported destination object

Valid values are `Hash`, `PathService`. 
[Back to overview of wls_saf_imported_destination_object](#attributes)


### use_saf_time_to_live_default<a name='wls_saf_imported_destination_object_use_saf_time_to_live_default'>

Controls whether the Time-to-Live (expiration time) value set on imported JMS messages will be overridden by the value specified in the <code>SAF Default Time-to-Live</code> field.  Any change to this parameter affects only incoming messages; stored messages are not affected.

An example on how to use this:

    wls_saf_imported_destination_object {a_wls_saf_imported_destination_object :
       ...
       use_saf_time_to_live_default => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_saf_imported_destination_object:use_saf_time_to_live_default']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_saf_imported_destination_object](#attributes)


### usetimetolivedefault<a name='wls_saf_imported_destination_object_usetimetolivedefault'>

use time to live default of this SAF imported destination

Valid values are `absent`, `1`, `0`. 
[Back to overview of wls_saf_imported_destination_object](#attributes)

