---
title: wls safagent
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage a SAF agent in an WebLogic domain.

Here is an example on how you should use this:

    wls_safagent { 'jmsSAFAgent1':
      ensure              => 'present',
      persistentstore     => 'jmsFileSAFAgent1',
      persistentstoretype => 'FileStore',
      servicetype         => 'Sending-only',
      target              => ['wlsServer1'],
      targettype          => ['Server'],
    }

In this example you are managing a SAF agent in the default domain. When you want to
manage a SAF agent in a specific domain, you can use:

    wls_safagent { 'my_domain/jmsSAFAgent2':
      ensure      => 'present',
      servicetype => 'Both',
      target      => ['wlsServer2'],
      targettype  => ['Server'],
    }

## Attributes



Attribute Name                                                                         | Short Description                                                                                                                        |
-------------------------------------------------------------------------------------- | ---------------------------------------------------------------------------------------------------------------------------------------- |
[acknowledge_interval](#wls_safagent_acknowledge_interval)                             | The maximum interval between two successive acknowledgements sent by the receiving side.                                                 |
[bytes_maximum](#wls_safagent_bytes_maximum)                                           | The maximum bytes quota (total amount of bytes) that can be stored in this SAF agent.                                                    |
[bytes_threshold_high](#wls_safagent_bytes_threshold_high)                             | The upper threshold value that triggers events based on the number of bytes stored in the SAF agent.                                     |
[bytes_threshold_low](#wls_safagent_bytes_threshold_low)                               | The lower threshold that triggers events based on the number of bytes stored in the SAF agent.                                           |
[conversation_idle_time_maximum](#wls_safagent_conversation_idle_time_maximum)         | The maximum amount of time allowed before a sending side releases the resources used by a conversation.                                  |
[default_retry_delay_base](#wls_safagent_default_retry_delay_base)                     | The amount of time, in milliseconds, between the original delivery attempt and the first retry.                                          |
[default_retry_delay_maximum](#wls_safagent_default_retry_delay_maximum)               | The maximum amount of time, in milliseconds, between two successive delivery retry attempts.                                             |
[default_retry_delay_multiplier](#wls_safagent_default_retry_delay_multiplier)         | The factor used to multiply the previous delay time to calculate the next delay time to be used.                                         |
[default_time_to_live](#wls_safagent_default_time_to_live)                             | The default amount of time, in milliseconds, that the agent guarantees to reliably send messages.                                        |
[deployment_order](#wls_safagent_deployment_order)                                     | A priority that the server uses to determine when it deploys an item.                                                                    |
[domain](#wls_safagent_domain)                                                         | With this parameter, you identify the domain, where your objects is in.                                                                  |
[ensure](#wls_safagent_ensure)                                                         | The basic property that the resource should be in.                                                                                       |
[forwarding_paused_at_startup](#wls_safagent_forwarding_paused_at_startup)             | Specifies whether the agent is paused for forwarding messages at the startup time.                                                       |
[incoming_paused_at_startup](#wls_safagent_incoming_paused_at_startup)                 | Specifies whether the agent is paused for incoming messages at startup time.                                                             |
[log_buffer_size_kb](#wls_safagent_log_buffer_size_kb)                                 | Gets the underlying log buffer size in kilobytes
                                                                                        |
[log_date_format_pattern](#wls_safagent_log_date_format_pattern)                       | The date format pattern used for rendering dates in the  log.                                                                            |
[log_file_count](#wls_safagent_log_file_count)                                         | The maximum number of log files that the server creates when it rotates the log.                                                         |
[log_file_min_size](#wls_safagent_log_file_min_size)                                   | The size (1 - 2097150 kilobytes) that triggers the server to move log messages to a separate file.                                       |
[log_file_name](#wls_safagent_log_file_name)                                           | 
                                                                                                                                        |
[log_file_rotation_dir](#wls_safagent_log_file_rotation_dir)                           | The directory where the rotated log files will be stored.                                                                                |
[log_file_time_span](#wls_safagent_log_file_time_span)                                 | The interval (in hours) at which the server saves old log messages to another file.                                                      |
[log_notes](#wls_safagent_log_notes)                                                   | Optional information that you can include to describe this configuration.                                                                |
[log_number_of_files_limited](#wls_safagent_log_number_of_files_limited)               | Indicates whether to limit the number of log files that this server instance creates to store old messages.                              |
[log_rotate_log_on_startup](#wls_safagent_log_rotate_log_on_startup)                   | Specifies whether a server rotates its log file during its startup cycle.                                                                |
[log_rotation_time](#wls_safagent_log_rotation_time)                                   | Determines the start time (hour and minute) for a time-based rotation sequence.                                                          |
[log_rotation_type](#wls_safagent_log_rotation_type)                                   | Criteria for moving old log messages to a separate file.                                                                                 |
[log_tags](#wls_safagent_log_tags)                                                     | Return all tags on this Configuration MBean
                                                                                             |
[logging_enabled](#wls_safagent_logging_enabled)                                       | Specifies whether a message is logged in the server log file when a message fails to be forwarded.                                       |
[maximum_message_size](#wls_safagent_maximum_message_size)                             | The maximum number of bytes allowed in individual messages on this SAF agent.                                                            |
[message_buffer_size](#wls_safagent_message_buffer_size)                               | The amount of memory used to store message bodies in memory before they are paged out to disk.                                           |
[message_compression_options](#wls_safagent_message_compression_options)               | Specifies the type of message compression used when JMS message body compression is enabled for Persistent Stores and JMS Paging Stores. |
[messages_maximum](#wls_safagent_messages_maximum)                                     | The maximum message quota (total amount of messages) that can be stored in this SAF agent.                                               |
[messages_threshold_high](#wls_safagent_messages_threshold_high)                       | The upper threshold that triggers events based on the number of messages stored in the SAF agent.                                        |
[messages_threshold_low](#wls_safagent_messages_threshold_low)                         | The low threshold that triggers events based on the number of messages stored in the SAF agent.                                          |
[name](#wls_safagent_name)                                                             | The name.                                                                                                                                |
[notes](#wls_safagent_notes)                                                           | Optional information that you can include to describe this configuration.                                                                |
[paging_directory](#wls_safagent_paging_directory)                                     |  Specifies where message bodies are written when the size of the message bodies in the JMS server exceeds the message buffer size.       |
[paging_message_compression_enabled](#wls_safagent_paging_message_compression_enabled) | Enables the JMS paging store to perform message body compression on persistent and non-persistent messages.                              |
[persistentstore](#wls_safagent_persistentstore)                                       | The persistentstore name
                                                                                                                |
[persistentstoretype](#wls_safagent_persistentstoretype)                               | The persistentstore type
                                                                                                                |
[provider](#wls_safagent_provider)                                                     | resource.                                                                                                                                |
[receiving_paused_at_startup](#wls_safagent_receiving_paused_at_startup)               | Specifies whether the agent is paused for receiving messages at the startup time.                                                        |
[safagent_name](#wls_safagent_safagent_name)                                           | The SAF agent name
                                                                                                                      |
[service_type](#wls_safagent_service_type)                                             | The type of service that this SAF agent provides.                                                                                        |
[servicetype](#wls_safagent_servicetype)                                               | The service type
                                                                                                                        |
[store](#wls_safagent_store)                                                           | The persistent disk-based file store or JDBC-accessible database for the SAF agent.                                                      |
[store_message_compression_enabled](#wls_safagent_store_message_compression_enabled)   | Enables the JMS store to perform message body compression.                                                                               |
[tags](#wls_safagent_tags)                                                             | Return all tags on this Configuration MBean
                                                                                             |
[target](#wls_safagent_target)                                                         | An array of target names.                                                                                                                |
[targettype](#wls_safagent_targettype)                                                 | An array of target types.                                                                                                                |
[timeout](#wls_safagent_timeout)                                                       | Timeout for applying a resource.                                                                                                         |
[window_interval](#wls_safagent_window_interval)                                       | The maximum amount of time, in milliseconds, that a JMS sending agent waits before forwarding messages in a single batch.                |
[window_size](#wls_safagent_window_size)                                               | For JMS messages, the number of messages in a batch.                                                                                     |




### acknowledge_interval<a name='wls_safagent_acknowledge_interval'>

The maximum interval between two successive acknowledgements sent by the receiving side.  <ul> <li> Applies only to agents with receiving capability. </li>  <li> A value of <code>-1</code> specifies that there is no time limit between successive acknowledgement. </li>  <li> Updating <code>AcknowlegeInterval</code> causes connections starting after the update to use the new value. </li> </ul>

An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       acknowledge_interval => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:acknowledge_interval']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_safagent](#attributes)


### bytes_maximum<a name='wls_safagent_bytes_maximum'>

The maximum bytes quota (total amount of bytes) that can be stored in this SAF agent.  <ul> <li> The default value of <code>-1</code> specifies that there is no WebLogic-imposed limit on the number of bytes that can be stored. However, excessive bytes volume can cause memory saturation, so this value should correspond to the total amount of available system memory relative to the rest of your application load. </li>  <li> Applies only to agents with sending capability. </li>  <li> Updating <code>BytesMaximum</code> affects only new requests. </li> </ul>  Range of Values: &gt;= BytesThresholdHigh

An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       bytes_maximum => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:bytes_maximum']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_safagent](#attributes)


### bytes_threshold_high<a name='wls_safagent_bytes_threshold_high'>

The upper threshold value that triggers events based on the number of bytes stored in the SAF agent.  <ul> <li> The default value of <code>-1</code>  disables the events for this SAF agent.  </li>  <li> Applies only to agents with sending capability. </li>  <li> Updating <code>BytesThresholdHigh</code> affects only new requests. </li>  <li> If the number of bytes exceeds this threshold, the triggered events are:  <ul> <li>Log Messages: A message is logged on the server indicating a high threshold condition. </li>  <li>Flow Control: The agent becomes armed and instructs producers to begin decreasing their message flow. </li> </ul> </li> </ul>  Range of Values: &lt;= BytesMaximum; &gt;= BytesThresholdLow

An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       bytes_threshold_high => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:bytes_threshold_high']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_safagent](#attributes)


### bytes_threshold_low<a name='wls_safagent_bytes_threshold_low'>

The lower threshold that triggers events based on the number of bytes stored in the SAF agent.  <ul> <li> The default value of <code>-1</code>  disables the events for this SAF agent.  </li>  <li> Applies only to agents with sending capability. </li>  <li> Updating <code>BytesThresholdLow</code> affects only new requests. </li>  <li> If the number of bytes falls below this threshold, the triggered events are:  <ul> <li>Log Messages: A message is logged on the server indicating that the threshold condition has cleared. </li>  <li>Flow Control: The agent becomes disarmed and instructs producers to begin increasing their message flow. </li> </ul> </li> </ul>  Range of Values: &lt;= BytesThresholdHigh

An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       bytes_threshold_low => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:bytes_threshold_low']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_safagent](#attributes)


### conversation_idle_time_maximum<a name='wls_safagent_conversation_idle_time_maximum'>

The maximum amount of time allowed before a sending side releases the resources used by a conversation.  <ul> <li> If there is no activity for a conversation for the specified amount of time, the sending agent releases all resources for that conversation and notifies the receiving agent to do the same. </li>  <li> A value of <code>0</code> specifies that resources for a conversation are not released unless the application explicitly closes the conversation. </li>  <li> Updating <code>ConversationIdleTimeMaximum</code> causes connections starting after the update to use the new value. </li> </ul>

An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       conversation_idle_time_maximum => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:conversation_idle_time_maximum']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_safagent](#attributes)


### default_retry_delay_base<a name='wls_safagent_default_retry_delay_base'>

The amount of time, in milliseconds, between the original delivery attempt and the first retry.  <ul> <li> If <code>RetryDelayMultiplier</code> is set to <code>1</code>, this defines the interval between any two successive retry attempts. </li>  <li> Applies only to agents with sending capability. </li>  <li> Updating <code>DefaultRetryDelayBase</code> causes connections starting after the update to use the new value. </li> </ul>  Range of Values: &lt;= RetryDelayMaximum if RetryDelayMultiplier is not 1.0.

An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       default_retry_delay_base => '20000'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:default_retry_delay_base']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_safagent](#attributes)


### default_retry_delay_maximum<a name='wls_safagent_default_retry_delay_maximum'>

The maximum amount of time, in milliseconds, between two successive delivery retry attempts.  <ul> <li> Applies only to agents with sending capability. </li>  <li> Updating <code>DefaultRetryDelayMaximum</code> causes connections starting after the update to use the new value. </li> </ul>  Range of Values: &gt; = RetryDelayBase if RetryDelayMultiplier is not 1.0.

An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       default_retry_delay_maximum => '180000'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:default_retry_delay_maximum']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_safagent](#attributes)


### default_retry_delay_multiplier<a name='wls_safagent_default_retry_delay_multiplier'>

The factor used to multiply the previous delay time to calculate the next delay time to be used.  <ul> <li> Applies only to agents with sending capability. </li>  <li> Updating <code>DefaultRetryDelayMuliplier</code> causes connections starting after the update to use the new value. </li> </ul>  Range of Values: &gt;= 1.

An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       default_retry_delay_multiplier => '1.0'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:default_retry_delay_multiplier']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_safagent](#attributes)


### default_time_to_live<a name='wls_safagent_default_time_to_live'>

The default amount of time, in milliseconds, that the agent guarantees to reliably send messages.  <ul> <li> A value of 0 means the agent guarantees to reliably send messages for the duration of the conversation. </li>  <li> Updating <code>DefaultTimeToLive</code> causes conversations starting after the update to use the new value. </li> </ul>

An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       default_time_to_live => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:default_time_to_live']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_safagent](#attributes)


### deployment_order<a name='wls_safagent_deployment_order'>

A priority that the server uses to determine when it deploys an item. The priority is relative to other deployable items of the same type.  For example, the server prioritizes and deploys all EJBs before it prioritizes and deploys startup classes.  Items with the lowest Deployment Order value are deployed first. There is no guarantee on the order of deployments with equal Deployment Order values. There is no guarantee of ordering across clusters.

An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       deployment_order => '1000'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:deployment_order']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_safagent](#attributes)


### domain<a name='wls_safagent_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.


[Back to overview of wls_safagent](#attributes)


### ensure<a name='wls_safagent_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 
[Back to overview of wls_safagent](#attributes)


### forwarding_paused_at_startup<a name='wls_safagent_forwarding_paused_at_startup'>

Specifies whether the agent is paused for forwarding messages at the startup time.  When enabled, the sending agent forwards messages. Otherwise, the sending agent does not forward any messages.

An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       forwarding_paused_at_startup => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:forwarding_paused_at_startup']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_safagent](#attributes)


### incoming_paused_at_startup<a name='wls_safagent_incoming_paused_at_startup'>

Specifies whether the agent is paused for incoming messages at startup time.  When enabled, the sending agent accepts new messages. Otherwise, the sending agent does not accept any new messages.

An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       incoming_paused_at_startup => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:incoming_paused_at_startup']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_safagent](#attributes)


### log_buffer_size_kb<a name='wls_safagent_log_buffer_size_kb'>

Gets the underlying log buffer size in kilobytes

An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       log_buffer_size_kb => '8'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:log_buffer_size_kb']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_safagent](#attributes)


### log_date_format_pattern<a name='wls_safagent_log_date_format_pattern'>

The date format pattern used for rendering dates in the  log. The DateFormatPattern string conforms to the specification of the <code>java.text.SimpleDateFormat</code> class.

An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       log_date_format_pattern => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:log_date_format_pattern']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_safagent](#attributes)


### log_file_count<a name='wls_safagent_log_file_count'>

The maximum number of log files that the server creates when it rotates the log. This number does not include the file that the server uses to store current messages. (Requires that you enable Number of Files Limited.)

An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       log_file_count => '7'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:log_file_count']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_safagent](#attributes)


### log_file_min_size<a name='wls_safagent_log_file_min_size'>

The size (1 - 2097150 kilobytes) that triggers the server to move log messages to a separate file. The default is 500 kilobytes. After the log file reaches the specified minimum size, the next time the server checks the file size, it will rename the current log file as <code>SERVER_NAME.lognnnnn</code> and create a new one to store subsequent messages. (Requires that you specify a file rotation type of <code>Size</code>.)

An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       log_file_min_size => '500'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:log_file_min_size']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_safagent](#attributes)


### log_file_name<a name='wls_safagent_log_file_name'>



An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       log_file_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:log_file_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_safagent](#attributes)


### log_file_rotation_dir<a name='wls_safagent_log_file_rotation_dir'>

The directory where the rotated log files will be stored. By default the rotated files are stored in the same directory where the log file is stored.

An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       log_file_rotation_dir => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:log_file_rotation_dir']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_safagent](#attributes)


### log_file_time_span<a name='wls_safagent_log_file_time_span'>

The interval (in hours) at which the server saves old log messages to another file. (Requires that you specify a file rotation type of <code>TIME</code>.)

An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       log_file_time_span => '24'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:log_file_time_span']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_safagent](#attributes)


### log_notes<a name='wls_safagent_log_notes'>

Optional information that you can include to describe this configuration.  WebLogic Server saves this note in the domain's configuration file (<code>config.xml</code>) as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  <dl> <dt>Note:</dt>  <dd> If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds. </dd> </dl>

An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       log_notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:log_notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_safagent](#attributes)


### log_number_of_files_limited<a name='wls_safagent_log_number_of_files_limited'>

Indicates whether to limit the number of log files that this server instance creates to store old messages. (Requires that you specify a file rotation type of <code>SIZE</code> or <code>TIME</code>.)  After the server reaches this limit, it deletes the oldest log file and creates a new log file with the latest suffix.  If you do not enable this option, the server creates new files indefinitely and you must clean up these files as you require.

An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       log_number_of_files_limited => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:log_number_of_files_limited']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_safagent](#attributes)


### log_rotate_log_on_startup<a name='wls_safagent_log_rotate_log_on_startup'>

Specifies whether a server rotates its log file during its startup cycle. The default value in production mode is false.

An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       log_rotate_log_on_startup => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:log_rotate_log_on_startup']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_safagent](#attributes)


### log_rotation_time<a name='wls_safagent_log_rotation_time'>

Determines the start time (hour and minute) for a time-based rotation sequence.  At the time that this value specifies, the server renames the current log file. Thereafter, the server renames the log file at an interval that you specify in File Time Span.  Note that WebLogic Server sets a threshold size limit of 500 MB before it forces a hard rotation to prevent excessive log file growth.   Use the following format: <code>H:mm</code>, where <ul><li><code>H</code> is Hour in day (0-23). <li><code>mm</code> is the minute in hour </ul>

An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       log_rotation_time => '00:00'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:log_rotation_time']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_safagent](#attributes)


### log_rotation_type<a name='wls_safagent_log_rotation_type'>

Criteria for moving old log messages to a separate file. <ul> <li><code>NONE</code> Messages accumulate in a single file. You must erase the contents of the file when the size is too large. Note that WebLogic Server sets a threshold size limit of 500 MB before it forces a hard rotation to prevent excessive log file growth.  <li><code>SIZE</code> When the log file reaches the size that you specify in <code>FileMinSize</code>, the server renames the file as <code>SERVER_NAME.lognnnnn</code>.  <li><code>TIME</code> At each time interval that you specify in <code>TimeSpan</code>, the server renames the file as <code>SERVER_NAME.lognnnnn</code>. </ul>  After the server renames a file, subsequent messages accumulate in a new file with the name that you specified as the log file name.

An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       log_rotation_type => 'bySize'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:log_rotation_type']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_safagent](#attributes)


### log_tags<a name='wls_safagent_log_tags'>

Return all tags on this Configuration MBean

An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       log_tags => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:log_tags']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_safagent](#attributes)


### logging_enabled<a name='wls_safagent_logging_enabled'>

Specifies whether a message is logged in the server log file when a message fails to be forwarded.  <ul> <li> If selected, this applies to messages that fail to be forwarded and delivered to the final destination when there is no error handling in a SAF application or the application's error handling fails. </li>  <li> Applies only to agents with receiving capability. </li>  <li> Updating <code>LoggingEnabled</code> causes connections starting after the update to use the new value. </li> </ul>

An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       logging_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:logging_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_safagent](#attributes)


### maximum_message_size<a name='wls_safagent_maximum_message_size'>

The maximum number of bytes allowed in individual messages on this SAF agent.  <ul> <li> The message size includes the message body, any user-defined properties, and the user-defined JMS header fields: <code>JMSCorrelationID</code> and <code>JMSType</code>. </li>  <li> Producers sending messages that exceed the configured maximum message size for the SAF agent will receive a <code>ResourceAllocationException</code>. </li>  <li> The maximum message size is only enforced for the initial production of a message. Messages that are redirected to an error destination or forwarded to a member of a distributed destination are not checked for size. For instance, if a destination and its corresponding error destination are configured with a maximum message size of 128K bytes and 64K bytes, respectively, a message of 96K bytes could be redirected to the error destination (even though it exceeds the 64K byte maximum), but a producer could not directly send the 96K byte message to the error destination. </li>  <li> Applies only to agents with sending capability. </li>  <li> Updating <code>MaximumMessageSize</code> affects only incoming messages; stored messages are not affected. </li> </ul>

An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       maximum_message_size => '2147483647'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:maximum_message_size']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_safagent](#attributes)


### message_buffer_size<a name='wls_safagent_message_buffer_size'>

The amount of memory used to store message bodies in memory before they are paged out to disk. <ul> <li> A value of -1 (the default) specifies that the server will automatically determine a size based on the maximum heap size of the JVM. This default will be set to either one-third the maximum heap size, or 512 megabytes, whichever is smaller. </li>  <li> The larger the buffer, the more memory JMS will consume when many messages are waiting on queues or topics. Once the buffer is surpassed, JMS may write message bodies to the directory specified by PagingDirectory in an effort to reduce memory usage below this buffer. </li>  <li> Surpassing the buffer size does not stop the JMS server from accepting new messages. It is still possible to run out of memory if messages are arriving faster than they can be written to disk. Users with high messaging loads who wish to support the highest possible availability should consider setting a quota or setting a threshold and enabling flow control. </li>  <li> Applies only to agents with sending capability. </li>  <li> Paging is always supported.  </li>  <li> Updating the memory size resets the message count so that only requests arriving after the update are charged against the new memory size. </li> </ul>

An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       message_buffer_size => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:message_buffer_size']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_safagent](#attributes)


### message_compression_options<a name='wls_safagent_message_compression_options'>

Specifies the type of message compression used when JMS message body compression is enabled for Persistent Stores and JMS Paging Stores. <ul> <li>Use <code>GZIP_DEFAULT_COMPRESSION</code> to enable message compression using the JDK GZIP API with <code>DEFAULT_COMPRESSION</code> level.</li> <li>Use <code>GZIP_BEST_COMPRESSION</code> to enable message compression using the JDK GZIP API with <code>BEST_COMPRESSION</code> level. <li>Use <code>GZIP_BEST_SPEED</code> to enable message compression using the JDK GZIP API with <code>BEST_SPEED</code> level. <li>Use <code>LZF</code> to enable message compression using Open Source LZF. </ul> This attribute should be used only when configuring a WebLogic domain in an Oracle Exalogic environment.

An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       message_compression_options => 'GZIP_DEFAULT_COMPRESSION'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:message_compression_options']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_safagent](#attributes)


### messages_maximum<a name='wls_safagent_messages_maximum'>

The maximum message quota (total amount of messages) that can be stored in this SAF agent.  <ul> <li> The default value of <code>-1</code> specifies that the server instance has no limit on the number of messages that can be stored. However, excessive message volume can cause memory saturation, so this value should correspond to the total amount of available system memory relative to the rest of your application load. </li>  <li> Applies only to sending agents. </li>  <li> Updating the maximum message quota resets the message count so that only requests arriving after the update are charged against the new quota. </li> </ul>  Range of Values: &gt;= MessagesThresholdHigh

An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       messages_maximum => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:messages_maximum']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_safagent](#attributes)


### messages_threshold_high<a name='wls_safagent_messages_threshold_high'>

The upper threshold that triggers events based on the number of messages stored in the SAF agent.  <ul> <li> The default value of <code>-1</code> disables the events for this SAF agent.  </li>  <li> Applies only to agents with sending capability. </li>  <li> Updating <code>MessagesThresholdHigh</code> affects only new requests. </li>  <li> If the number of messages exceeds this threshold, the triggered events are:  <ul> <li>Log Messages: A message is logged on the server indicating a high threshold condition. </li>  <li>Flow Control: The agent becomes armed and instructs producers to begin decreasing their message flow. </li> </ul> </li> </ul>  Range of Values: &lt;= MessagesMaximum; &gt;= MessagesThresholdLow

An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       messages_threshold_high => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:messages_threshold_high']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_safagent](#attributes)


### messages_threshold_low<a name='wls_safagent_messages_threshold_low'>

The low threshold that triggers events based on the number of messages stored in the SAF agent.  <ul> <li> The default value of <code>-1</code> disables the events for this SAF agent.  </li>  <li> Applies only to agents with sending capability. </li>  <li> Updating <code>MessagesThresholdLow</code> affects only new requests. </li>  <li> If the number of messages falls below this threshold, the triggered events are:  <ul> <li>Log Messages: A message is logged on the server indicating that the threshold condition has cleared. </li>  <li>Flow Control: The agent becomes disarmed and instructs producers to begin increasing their message flow. </li> </ul> </li> </ul>  Range of Values: &lt;= MessagesThresholdHigh.

An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       messages_threshold_low => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:messages_threshold_low']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_safagent](#attributes)


### name<a name='wls_safagent_name'>

The name.


[Back to overview of wls_safagent](#attributes)


### notes<a name='wls_safagent_notes'>

Optional information that you can include to describe this configuration.  WebLogic Server saves this note in the domain's configuration file (<code>config.xml</code>) as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  <dl> <dt>Note:</dt>  <dd> If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds. </dd> </dl>

An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_safagent](#attributes)


### paging_directory<a name='wls_safagent_paging_directory'>

 Specifies where message bodies are written when the size of the message bodies in the JMS server exceeds the message buffer size. If unspecified, messages are written to the <code>tmp</code> directory in the host WebLogic Server instance's directory. For example, <code><em>domainName</em>/servers/<em>servername</em>/tmp</code>.   <ul> <li> For best performance, this directory should not be the same as the directory used by the SAF agent's persistent store. </li>  <li> Applies only to agents with sending capability. </li> </ul>

An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       paging_directory => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:paging_directory']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_safagent](#attributes)


### paging_message_compression_enabled<a name='wls_safagent_paging_message_compression_enabled'>

Enables the JMS paging store to perform message body compression on persistent and non-persistent messages. When <code>false</code>, the default value, no compression is performed. This attribute should be enabled only when configuring a WebLogic domain in an Oracle Exalogic environment.

An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       paging_message_compression_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:paging_message_compression_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_safagent](#attributes)


### persistentstore<a name='wls_safagent_persistentstore'>

The persistentstore name


[Back to overview of wls_safagent](#attributes)


### persistentstoretype<a name='wls_safagent_persistentstoretype'>

The persistentstore type

Valid values are `FileStore`, `JDBCStore`. 
[Back to overview of wls_safagent](#attributes)


### provider<a name='wls_safagent_provider'>

The specific backend to use for this `wls_safagent`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: safagent server in an WebLogic domain via regular WLST


[Back to overview of wls_safagent](#attributes)


### receiving_paused_at_startup<a name='wls_safagent_receiving_paused_at_startup'>

Specifies whether the agent is paused for receiving messages at the startup time.  When enabled, the sending agent receives messages. Otherwise, the sending agent does not receive any messages.

An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       receiving_paused_at_startup => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:receiving_paused_at_startup']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_safagent](#attributes)


### safagent_name<a name='wls_safagent_safagent_name'>

The SAF agent name


[Back to overview of wls_safagent](#attributes)


### service_type<a name='wls_safagent_service_type'>

The type of service that this SAF agent provides. JMS requires only a Sending agent on the sending side for messages. Whereas, Web Services Reliable Messaging requires both a Sending and Receiving agent for messages. <ul> <li>Sending-only Configures an agent that stores messages in persistent storage, forwards messages to the receiving side, and re-transmits messages when acknowledgements do not come back in time. <li>Receiving-only Configures an agent that detects and eliminates duplicate messages sent by a receiving agent, and delivers messages to the final destination. <li>Both Configures an agent that has sending and receiving agent functionality. </ul>

An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       service_type => 'Both'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:service_type']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_safagent](#attributes)


### servicetype<a name='wls_safagent_servicetype'>

The service type

Valid values are `absent`, `Sending-only`, `Receiving-only`, `Both`. 
[Back to overview of wls_safagent](#attributes)


### store<a name='wls_safagent_store'>

The persistent disk-based file store or JDBC-accessible database for the SAF agent.  If a store is not configured, the server's default store is used.

An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       store => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:store']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_safagent](#attributes)


### store_message_compression_enabled<a name='wls_safagent_store_message_compression_enabled'>

Enables the JMS store to perform message body compression. When set to <code>false</code>, the default value, no compression is performed. This attribute should be enabled only when configuring a WebLogic domain in an Oracle Exalogic environment.

An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       store_message_compression_enabled => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:store_message_compression_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_safagent](#attributes)


### tags<a name='wls_safagent_tags'>

Return all tags on this Configuration MBean

An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       tags => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:tags']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_safagent](#attributes)


### target<a name='wls_safagent_target'>

An array of target names.

The array of targets for this resource. A target can be a WebLogic Server, a WebLogic cluster, or a JMS Server.
When specifying a `target`, you'll also have to specify `targettype`. Here is an example on how you can specify a `target`.

    ..{ 'aResource':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }

here is an example on specifying the `target` and `targettype` for a regular WebLogic cluster:

    wls_cluster{ 'aCluster':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }


[Back to overview of wls_safagent](#attributes)


### targettype<a name='wls_safagent_targettype'>

An array of target types.

The array of target types for this resource. A target can be a WebLogic Server, a WebLogic cluster, or a JMS Server.
When specifying a `targettype`, you'll also have to specify a `target`. Here is an example on how you can specify a `target`.

    ...{ 'aResource':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }

here is an example on specifying the `target` and `targettype` for a regular WebLogic cluster:

    wls_cluster{ 'aCluster':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }


[Back to overview of wls_safagent](#attributes)


### timeout<a name='wls_safagent_timeout'>

Timeout for applying a resource.

To be sure no Puppet operation, hangs a Puppet daemon, all operations have a timeout. When this timeout
expires, Puppet will abort the current operation and signal an error in the Puppet run.

With this parameter, you can specify the length of the timeout. The value is specified in seconds. In
this example, the `timeout`  is set to `600`  seconds.

    wls_server{'my_server':
      ...
      timeout => 600,
    }

The default value for `timeout` is 120 seconds.


[Back to overview of wls_safagent](#attributes)


### window_interval<a name='wls_safagent_window_interval'>

The maximum amount of time, in milliseconds, that a JMS sending agent waits before forwarding messages in a single batch. For a distributed queue or topic, <code>WindowInterval</code> setting is ignored.  A sending agent waits to forward the message batch until either: (A) the source destination message count is greater than or equal to the configured <code>Window Size</code>; (B) it has waited a specified <code>Window Interval</code>, whichever comes first.

An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       window_interval => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:window_interval']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_safagent](#attributes)


### window_size<a name='wls_safagent_window_size'>

For JMS messages, the number of messages in a batch. A sending agent waits to forward a message batch until the source destination message count is greater than or equal to this value. For a distributed queue or topic, <code>WindowSize</code> setting is ignored and always internally set to 1 message. For WSRM, the maximum number of unacknowledged messages allowed between a source destination and a target destination during a conversation.

An example on how to use this:

    wls_safagent {a_wls_safagent :
       ...
       window_size => '10'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_safagent:window_size']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_safagent](#attributes)

