---
title: wls setting
keywords: documentation
layout: documentation
sidebar: _sidebar
toc: false
---
## Overview

This resource allows you to set the defaults for all other wls types.


All wls types needs a `wls_setting` definition. This is a pointer to an WebLogic AdminServer and
you need to create one for every WebLogic domain. When you don't provide a `wls_setting` identifier
in the title of the weblogic type then it will use `default` as identifier.

Here is an example on how to create the `default` settings:

    wls_setting { 'default':
      user               => 'oracle',
      weblogic_home_dir  => '/opt/oracle/middleware11g/wlserver_10.3',
      connect_url        => "t3://localhost:7001",
      weblogic_user      => 'weblogic',
      weblogic_password  => 'weblogic1',
    }

When you want to create an other domain, like for instance `domain2`. You use `wls_setting like this:

    wls_setting { 'domain2':
      user               => 'oracle',
      weblogic_home_dir  => '/opt/oracle/middleware11g/wlserver_10.3',
      connect_url        => "t3://localhost:7011",
      weblogic_user      => 'weblogic',
      weblogic_password  => 'weblogic1',
      post_classpath     => '/opt/oracle/wlsdomains/domains/Wls1036/lib/aa.jar',
      extra_properties   => ['wls_server:.*'],
    }

## Attributes



Attribute Name                                                      | Short Description                                  |
------------------------------------------------------------------- | -------------------------------------------------- |
[archive_path](#wls_setting_archive_path)                           | the archive path for WLST scripts we want to keep
 |
[connect_url](#wls_setting_connect_url)                             | The url to connect to
                             |
[custom_trust](#wls_setting_custom_trust)                           | The custom trust enabled
                          |
[debug_module](#wls_setting_debug_module)                           | Toggles retaining of WLST Python scripts
          |
[extra_properties](#wls_setting_extra_properties)                   | The extra properties to use.                       |
[name](#wls_setting_name)                                           | The name of the setting
                           |
[post_classpath](#wls_setting_post_classpath)                       | the post classpath
                                |
[provider](#wls_setting_provider)                                   | resource.                                          |
[trust_keystore_file](#wls_setting_trust_keystore_file)             | The trust keystore file
                           |
[trust_keystore_passphrase](#wls_setting_trust_keystore_passphrase) | The trust keystore passphrase
                     |
[user](#wls_setting_user)                                           | Operating System user
                             |
[weblogic_home_dir](#wls_setting_weblogic_home_dir)                 | The WLS homedir
                                   |
[weblogic_password](#wls_setting_weblogic_password)                 | weblogic password
                                 |
[weblogic_user](#wls_setting_weblogic_user)                         | the weblogic user account
                         |




### archive_path<a name='wls_setting_archive_path'>

the archive path for WLST scripts we want to keep


[Back to overview of wls_setting](#attributes)


### connect_url<a name='wls_setting_connect_url'>

The url to connect to


[Back to overview of wls_setting](#attributes)


### custom_trust<a name='wls_setting_custom_trust'>

The custom trust enabled

Valid values are `true`, `false`. 
[Back to overview of wls_setting](#attributes)


### debug_module<a name='wls_setting_debug_module'>

Toggles retaining of WLST Python scripts

Valid values are `true`, `false`. 
[Back to overview of wls_setting](#attributes)


### extra_properties<a name='wls_setting_extra_properties'>

The extra properties to use.

Besides all the properties of the WebLogic types that are always loaded, you can use a set of extra properties.
To enable these extra properties, you'll have to enabled them in de settings for this domain. You can do this
useing the `extra_properties` property of `wls_setting`.

This is an array of elements. Each element is a regular expression specifying one or more
types with attributes. An example:

  wls_setting {'default':
    ...
    extra_properties => [
      'wls_server:.*',      # Include all extra properties from wls_server
      'wls_domain:.*ssl.*', # include all extra properties containg the string ssl for type wls_domain
    ]
    ...
  }


[Back to overview of wls_setting](#attributes)


### name<a name='wls_setting_name'>

The name of the setting


[Back to overview of wls_setting](#attributes)


### post_classpath<a name='wls_setting_post_classpath'>

the post classpath


[Back to overview of wls_setting](#attributes)


### provider<a name='wls_setting_provider'>

The specific backend to use for this `wls_setting`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

yaml
: Manage wls settings through yaml file


[Back to overview of wls_setting](#attributes)


### trust_keystore_file<a name='wls_setting_trust_keystore_file'>

The trust keystore file


[Back to overview of wls_setting](#attributes)


### trust_keystore_passphrase<a name='wls_setting_trust_keystore_passphrase'>

The trust keystore passphrase


[Back to overview of wls_setting](#attributes)


### user<a name='wls_setting_user'>

Operating System user


[Back to overview of wls_setting](#attributes)


### weblogic_home_dir<a name='wls_setting_weblogic_home_dir'>

The WLS homedir


[Back to overview of wls_setting](#attributes)


### weblogic_password<a name='wls_setting_weblogic_password'>

weblogic password


[Back to overview of wls_setting](#attributes)


### weblogic_user<a name='wls_setting_weblogic_user'>

the weblogic user account


[Back to overview of wls_setting](#attributes)

