---
title: wls user
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage user in an WebLogic Security Realm.

Here is an example on how you should use this:

    wls_user { 'OracleSystemUser':
      ensure                 => 'present',
      authenticationprovider => 'DefaultAuthenticator',
      description            => 'Oracle application software system user.',
      realm                  => 'myrealm',
    }

In this example you are managing a user in the default domain. When you want to
manage a user in a specific domain, you can use:

    # this will use default as wls_setting identifier
    wls_user { 'my_domain/testuser1':
      ensure                 => 'present',
      authenticationprovider => 'DefaultAuthenticator',
      description            => 'testuser1',
      realm                  => 'myrealm',
    }

## Attributes



Attribute Name                                             | Short Description                                                       |
---------------------------------------------------------- | ----------------------------------------------------------------------- |
[authenticationprovider](#wls_user_authenticationprovider) | The security authentication providers of the domain.                    |
[description](#wls_user_description)                       | The user description
                                                   |
[domain](#wls_user_domain)                                 | With this parameter, you identify the domain, where your objects is in. |
[ensure](#wls_user_ensure)                                 | The basic property that the resource should be in.                      |
[name](#wls_user_name)                                     | The name.                                                               |
[password](#wls_user_password)                             | The weblogic artifacts password.                                        |
[provider](#wls_user_provider)                             | resource.                                                               |
[realm](#wls_user_realm)                                   | The security realm of the domain
                                       |
[timeout](#wls_user_timeout)                               | Timeout for applying a resource.                                        |
[user_name](#wls_user_user_name)                           | The user name.                                                          |




### authenticationprovider<a name='wls_user_authenticationprovider'>

The security authentication providers of the domain.


[Back to overview of wls_user](#attributes)


### description<a name='wls_user_description'>

The user description


[Back to overview of wls_user](#attributes)


### domain<a name='wls_user_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.


[Back to overview of wls_user](#attributes)


### ensure<a name='wls_user_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 
[Back to overview of wls_user](#attributes)


### name<a name='wls_user_name'>

The name.


[Back to overview of wls_user](#attributes)


### password<a name='wls_user_password'>

The weblogic artifacts password.


[Back to overview of wls_user](#attributes)


### provider<a name='wls_user_provider'>

The specific backend to use for this `wls_user`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage users of a WebLogic Security REALM


[Back to overview of wls_user](#attributes)


### realm<a name='wls_user_realm'>

The security realm of the domain


[Back to overview of wls_user](#attributes)


### timeout<a name='wls_user_timeout'>

Timeout for applying a resource.

To be sure no Puppet operation, hangs a Puppet daemon, all operations have a timeout. When this timeout
expires, Puppet will abort the current operation and signal an error in the Puppet run.

With this parameter, you can specify the length of the timeout. The value is specified in seconds. In
this example, the `timeout`  is set to `600`  seconds.

    wls_server{'my_server':
      ...
      timeout => 600,
    }

The default value for `timeout` is 120 seconds.


[Back to overview of wls_user](#attributes)


### user_name<a name='wls_user_user_name'>

The user name.


[Back to overview of wls_user](#attributes)

