---
title: wls workmanager
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage workmanagers in an WebLogic domain.

Here is an example on how you should use this:

    wls_workmanager { 'WorkManagerConstraints':
      ensure                => 'present',
      capacity              => 'CapacityConstraint',
      maxthreadsconstraint  => 'MaxThreadsConstraint',
      minthreadsconstraint  => 'MinThreadsConstraint',
      fairsharerequestclass => 'FairShareReqClass',
      stuckthreads          => '0',
      target                => ['WebCluster'],
      targettype            => ['Cluster'],
    }

In this example you are managing a work manager in the default domain. When you want to
manage a work manager in a specific domain, you can use:

    wls_workmanager { 'my_domain/WorkManagerConstraints':
      ensure                => 'present',
      capacity              => 'CapacityConstraint',
      maxthreadsconstraint  => 'MaxThreadsConstraint',
      minthreadsconstraint  => 'MinThreadsConstraint',
      fairsharerequestclass => 'FairShareReqClass',
      stuckthreads          => '0',
      target                => ['WebCluster'],
      targettype            => ['Cluster'],
    }

## Attributes



Attribute Name                                                                  | Short Description                                                                   |
------------------------------------------------------------------------------- | ----------------------------------------------------------------------------------- |
[application_scope](#wls_workmanager_application_scope)                         | Specifies whether this work manager should be scoped to an application.             |
[capacity](#wls_workmanager_capacity)                                           | The capacity constraint name
                                                       |
[context_request_class](#wls_workmanager_context_request_class)                 | The mapping of Request Classes to security names and groups.                        |
[deployment_order](#wls_workmanager_deployment_order)                           | A priority that the server uses to determine when it deploys an item.               |
[domain](#wls_workmanager_domain)                                               | With this parameter, you identify the domain, where your objects is in.             |
[ensure](#wls_workmanager_ensure)                                               | The basic property that the resource should be in.                                  |
[fair_share_request_class](#wls_workmanager_fair_share_request_class)           | Get the FairShareRequestClass for this WorkManager
                                 |
[fairsharerequestclass](#wls_workmanager_fairsharerequestclass)                 | The fairshare request class name
                                                   |
[ignore_stuck_threads](#wls_workmanager_ignore_stuck_threads)                   | Specifies whether this Work Manager ignores "stuck" threads.                        |
[max_threads_constraint](#wls_workmanager_max_threads_constraint)               | The maximum number of concurrent threads that can be allocated to execute requests. |
[maxthreadsconstraint](#wls_workmanager_maxthreadsconstraint)                   | The max threads constraint name
                                                    |
[min_threads_constraint](#wls_workmanager_min_threads_constraint)               | The minimum number of threads allocated to resolve deadlocks.                       |
[minthreadsconstraint](#wls_workmanager_minthreadsconstraint)                   | The min threads constraint name
                                                    |
[name](#wls_workmanager_name)                                                   | The name.                                                                           |
[notes](#wls_workmanager_notes)                                                 | Optional information that you can include to describe this configuration.           |
[provider](#wls_workmanager_provider)                                           | resource.                                                                           |
[response_time_request_class](#wls_workmanager_response_time_request_class)     | The response time goal (in milliseconds).                                           |
[stuckthreads](#wls_workmanager_stuckthreads)                                   | The stuckthreads of a workmanager
                                                  |
[tags](#wls_workmanager_tags)                                                   | Return all tags on this Configuration MBean
                                        |
[target](#wls_workmanager_target)                                               | An array of target names.                                                           |
[targettype](#wls_workmanager_targettype)                                       | An array of target types.                                                           |
[timeout](#wls_workmanager_timeout)                                             | Timeout for applying a resource.                                                    |
[work_manager_shutdown_trigger](#wls_workmanager_work_manager_shutdown_trigger) | Configure a shutdown trigger for this WorkManager.                                  |
[workmanager_name](#wls_workmanager_workmanager_name)                           | The workmanager name
                                                               |




### application_scope<a name='wls_workmanager_application_scope'>

Specifies whether this work manager should be scoped to an application. By default, work managers are scoped to an application. Set this value to false if the work manager is to be scoped to a domain

An example on how to use this:

    wls_workmanager {a_wls_workmanager :
       ...
       application_scope => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_workmanager:application_scope']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_workmanager](#attributes)


### capacity<a name='wls_workmanager_capacity'>

The capacity constraint name


[Back to overview of wls_workmanager](#attributes)


### context_request_class<a name='wls_workmanager_context_request_class'>

The mapping of Request Classes to security names and groups.

An example on how to use this:

    wls_workmanager {a_wls_workmanager :
       ...
       context_request_class => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_workmanager:context_request_class']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_workmanager](#attributes)


### deployment_order<a name='wls_workmanager_deployment_order'>

A priority that the server uses to determine when it deploys an item. The priority is relative to other deployable items of the same type.  For example, the server prioritizes and deploys all EJBs before it prioritizes and deploys startup classes.  Items with the lowest Deployment Order value are deployed first. There is no guarantee on the order of deployments with equal Deployment Order values. There is no guarantee of ordering across clusters.

An example on how to use this:

    wls_workmanager {a_wls_workmanager :
       ...
       deployment_order => '1000'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_workmanager:deployment_order']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_workmanager](#attributes)


### domain<a name='wls_workmanager_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.


[Back to overview of wls_workmanager](#attributes)


### ensure<a name='wls_workmanager_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 
[Back to overview of wls_workmanager](#attributes)


### fair_share_request_class<a name='wls_workmanager_fair_share_request_class'>

Get the FairShareRequestClass for this WorkManager

An example on how to use this:

    wls_workmanager {a_wls_workmanager :
       ...
       fair_share_request_class => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_workmanager:fair_share_request_class']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_workmanager](#attributes)


### fairsharerequestclass<a name='wls_workmanager_fairsharerequestclass'>

The fairshare request class name


[Back to overview of wls_workmanager](#attributes)


### ignore_stuck_threads<a name='wls_workmanager_ignore_stuck_threads'>

Specifies whether this Work Manager ignores "stuck" threads. Typically, stuck threads will cause the associated Work Manager to take some action: either switching the application to Admin mode, shutting down the server, or shutting down the Work Manager. If this flag is set, then no thread in this Work Manager is ever considered stuck.  If you do not explicitly specify IGNORE_STUCK_THREADS=TRUE, the default behavior is that upon encountering stuck threads, the server will take one of the aforementioned actions.

An example on how to use this:

    wls_workmanager {a_wls_workmanager :
       ...
       ignore_stuck_threads => '1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_workmanager:ignore_stuck_threads']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `0`, `1`. 
[Back to overview of wls_workmanager](#attributes)


### max_threads_constraint<a name='wls_workmanager_max_threads_constraint'>

The maximum number of concurrent threads that can be allocated to execute requests.

An example on how to use this:

    wls_workmanager {a_wls_workmanager :
       ...
       max_threads_constraint => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_workmanager:max_threads_constraint']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_workmanager](#attributes)


### maxthreadsconstraint<a name='wls_workmanager_maxthreadsconstraint'>

The max threads constraint name


[Back to overview of wls_workmanager](#attributes)


### min_threads_constraint<a name='wls_workmanager_min_threads_constraint'>

The minimum number of threads allocated to resolve deadlocks.

An example on how to use this:

    wls_workmanager {a_wls_workmanager :
       ...
       min_threads_constraint => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_workmanager:min_threads_constraint']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_workmanager](#attributes)


### minthreadsconstraint<a name='wls_workmanager_minthreadsconstraint'>

The min threads constraint name


[Back to overview of wls_workmanager](#attributes)


### name<a name='wls_workmanager_name'>

The name.


[Back to overview of wls_workmanager](#attributes)


### notes<a name='wls_workmanager_notes'>

Optional information that you can include to describe this configuration.  WebLogic Server saves this note in the domain's configuration file (<code>config.xml</code>) as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  <dl> <dt>Note:</dt>  <dd> If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds. </dd> </dl>

An example on how to use this:

    wls_workmanager {a_wls_workmanager :
       ...
       notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_workmanager:notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_workmanager](#attributes)


### provider<a name='wls_workmanager_provider'>

The specific backend to use for this `wls_workmanager`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage workmanagers of a WebLogic domain


[Back to overview of wls_workmanager](#attributes)


### response_time_request_class<a name='wls_workmanager_response_time_request_class'>

The response time goal (in milliseconds).

An example on how to use this:

    wls_workmanager {a_wls_workmanager :
       ...
       response_time_request_class => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_workmanager:response_time_request_class']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_workmanager](#attributes)


### stuckthreads<a name='wls_workmanager_stuckthreads'>

The stuckthreads of a workmanager

Valid values are `absent`, `1`, `0`. 
[Back to overview of wls_workmanager](#attributes)


### tags<a name='wls_workmanager_tags'>

Return all tags on this Configuration MBean

An example on how to use this:

    wls_workmanager {a_wls_workmanager :
       ...
       tags => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_workmanager:tags']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_workmanager](#attributes)


### target<a name='wls_workmanager_target'>

An array of target names.

The array of targets for this resource. A target can be a WebLogic Server, a WebLogic cluster, or a JMS Server.
When specifying a `target`, you'll also have to specify `targettype`. Here is an example on how you can specify a `target`.

    ..{ 'aResource':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }

here is an example on specifying the `target` and `targettype` for a regular WebLogic cluster:

    wls_cluster{ 'aCluster':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }


[Back to overview of wls_workmanager](#attributes)


### targettype<a name='wls_workmanager_targettype'>

An array of target types.

The array of target types for this resource. A target can be a WebLogic Server, a WebLogic cluster, or a JMS Server.
When specifying a `targettype`, you'll also have to specify a `target`. Here is an example on how you can specify a `target`.

    ...{ 'aResource':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }

here is an example on specifying the `target` and `targettype` for a regular WebLogic cluster:

    wls_cluster{ 'aCluster':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }


[Back to overview of wls_workmanager](#attributes)


### timeout<a name='wls_workmanager_timeout'>

Timeout for applying a resource.

To be sure no Puppet operation, hangs a Puppet daemon, all operations have a timeout. When this timeout
expires, Puppet will abort the current operation and signal an error in the Puppet run.

With this parameter, you can specify the length of the timeout. The value is specified in seconds. In
this example, the `timeout`  is set to `600`  seconds.

    wls_server{'my_server':
      ...
      timeout => 600,
    }

The default value for `timeout` is 120 seconds.


[Back to overview of wls_workmanager](#attributes)


### work_manager_shutdown_trigger<a name='wls_workmanager_work_manager_shutdown_trigger'>

Configure a shutdown trigger for this WorkManager. Specifies the condition to be used to shutdown the WorkManager. The Server health monitoring periodically checks to see if the conidtion is met and shuts down the work manager if needed.

An example on how to use this:

    wls_workmanager {a_wls_workmanager :
       ...
       work_manager_shutdown_trigger => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_workmanager:work_manager_shutdown_trigger']
       ...
    }

This help text generated from MBean text of the WebLogic server.


[Back to overview of wls_workmanager](#attributes)


### workmanager_name<a name='wls_workmanager_workmanager_name'>

The workmanager name


[Back to overview of wls_workmanager](#attributes)

