#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  Type.newtype(:wls_coherence_server) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-EOD
    This resource allows you to manage a coherence server in an WebLogic domain.

    Here is an example on how you should use this:

        wls_coherence_server { 'default':
          ensure         => 'present',
          server         => 'LocalMachine',
          unicastaddress => 'localhost',
          unicastport    => '8888',
        }

    In this example you are managing a server in the default domain. When you want to
    manage a coherence server in a specific domain, you can use:

        wls_coherence_server { 'my_domain/default':
          ensure         => 'present',
          server         => 'LocalMachine',
          unicastaddress => 'localhost',
          unicastport    => '8888',
        }

    Check [the Oracle Weblogic documentation](https://docs.oracle.com/middleware/1212/coherence/COHMG/toc.htm)
    for more documentation about setting up and managing a coherence server.

    EOD


    bean_type('CoherenceServer')

    ensurable
    parameter :domain
    parameter :name
    parameter :coherence_server_name
    property  :machine
    property :autorestart
    property :restartdelay
    property :restartinterval
    property :restartmax
    property :unicastaddress
    property :unicastport
    property :classpath
    extraproperties do
      property :coherence_cluster_system_resource
      property :nm_socket_create_timeout_in_millis
      property :notes
      property :restart_delay_seconds
      property :restart_interval_seconds
      property :restart_max
      property :start_notes
      property :unicast_listen_address
      property :unicast_listen_port
      property :unicast_port_auto_adjust
      #
      # Weblogic 12.2.1 new properties
      #
      property :start_arguments
      property :start_bea_home
      property :start_class_path
      property :start_java_home
      property :start_java_vendor
      property :start_mw_home
      property :start_root_directory
      property :start_tags
      property :tags
      property :unicast_port_auto_adjust_attempts
    end

    add_title_attributes(:coherence_server_name)
  end
end
