#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:xa_end_only_once, :parent => Puppet::Parameter::WlsProperty) do
  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  desc <<-EOD
  Specifies that <code>XAResource.end()</code> is called only once for each pending <code>XAResource.start()</code>.  This option prevents the XA driver from calling <code>XAResource.end(TMSUSPEND)</code> and <code>XAResource.end(TMSUCCESS)</code> successively. Only applies to data sources that use an XA driver.  Use this setting to work around specific problems with JDBC XA drivers. 

  An example on how to use this:

      wls_datasource {a_wls_datasource :
         ...
         xa_end_only_once => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_datasource:xa_end_only_once']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('JDBCResource/%{datasource_name}/JDBCXAParams/%{datasource_name}/XaEndOnlyOnce')
end
