#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  #
  Type.newtype(:wls_group) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-EOD
    This resource allows you to manage group in a WebLogic Security Realm.

    Here is an example on how you should use this:

        wls_group { 'SuperUsers':
          ensure                 => 'present',
          authenticationprovider => 'DefaultAuthenticator',
          description            => 'SuperUsers',
          realm                  => 'myrealm',
          users                  => ['testuser2'],
        }

    In this example you are managing a group in the default domain. When you want to
    manage a group in a specific domain, you can use:

        wls_group { 'my_domain/TestGroup':
          ensure                 => 'present',
          authenticationprovider => 'DefaultAuthenticator',
          description            => 'TestGroup',
          realm                  => 'myrealm',
          users                  => ['testuser1','testuser2'],
        }

    EOD

    ensurable

    to_get_raw_resources do
      Puppet.info "index #{name} "
      environment = { 'action' => 'index', 'type' => 'wls_group' }
      wlst template('wls_config/wls_group/index.py.erb', binding), environment
    end

    on_create do
      Puppet.info "create #{name} "
      wlst template('wls_config/wls_group/create.py.erb', binding)
      nil
    end

    on_modify do
      Puppet.info "modify #{name} "
      wlst template('wls_config/wls_group/modify.py.erb', binding)
    end

    on_destroy do
      Puppet.info "destroy #{name} "
      wlst template('wls_config/wls_group/destroy.py.erb', binding)
      nil
    end

    parameter :domain
    parameter :name
    parameter :group_name
    parameter :timeout
    property :realm
    property :authenticationprovider
    property :users
    property :description

    add_title_attributes(:group_name)
  end
end
