#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  #
  Type.newtype(:wls_jms_module) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-EOD
    This resource allows you to manage a JMS module in an WebLogic domain.

    Here is an example on how you should use this:

        wls_jms_module { 'jmsClusterModule':
          ensure     => 'present',
          target     => ['WebCluster'],
          targettype => ['Cluster'],
        }

    In this example you are managing a JMS module in the default domain. When you want to
    manage a JMS module in a specific domain, you can use:

        wls_jms_module { 'my_domain/jmsClusterModule':
          ensure     => 'present',
          target     => ['WebCluster'],
          targettype => ['Cluster'],
        }

    EOD

    bean_type('JMSSystemResource')

    ensurable
    parameter :domain
    parameter :name
    parameter :jms_module_name
    parameter :timeout
    property  :policyexpression
    property :target
    property :targettype
    extraproperties do
      property :compatibility_name
      property :deployment_order
      property :deployment_principal_name
      property :module_type
      property :notes
      property :source_path
      #
      # Weblogic 12.2.1 new properties
      #
      property :tags
    end


    def on_destroy
      wls_config.set_security_policy('JMSModule', jms_module_name, '', 'absent')
      super
    end

    add_title_attributes(:jms_module_name)
  end
end
