#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:delivery_expiration_policy, :parent => Puppet::Parameter::WlsProperty) do

  desc <<-EOD
  The message Expiration Policy to use when an expired message is encountered on a destination. The valid expiration policies are:  None - Same as the Discard policy; expired messages are simply removed from the destination.  Discard - Removes expired messages from the messaging system. The removal is not logged and the message is not redirected to another location. If no value is defined for a given destination (i.e., None), then expired messages are discarded.  Log - Removes expired messages from the system and writes an entry to the server log file indicating that the messages have been removed from the system. The actual information that is logged is defined by the Expiration Logging Policy.  Redirect - Moves expired messages from their current location to the Error Destination defined for the destination. The message retains its body, and all of its properties. The message also retains all of its header fields, but with the following exceptions: <ul> <li> The destination for the message becomes the error destination. <li> All property overrides associated with the error destination are applied to the redirected message. <li> If there is no Time-To-Live Override value for the error destination, then the message receives a new Expiration Time of zero (indicating that it will not expire again). </ul>  It is illegal to use the Redirect policy when there is no valid error destination defined for the destination. Similarly, it is illegal to remove the error destination for a destination that is using the Redirect policy.  Note: The Maximum Message quota is only enforced for sending new messages. It is ignored when moving messages because of the Redirect policy. 

  An example on how to use this:

      wls_jms_template {a_wls_jms_template :
         ...
         delivery_expiration_policy => 'Discard'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_template:delivery_expiration_policy']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('DeliveryFailureParams/%{template_name}/ExpirationPolicy')
end
