#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:maximum_message_size, :parent => Puppet::Parameter::WlsProperty) do
  

  desc <<-EOD
  The maximum size of a message that is accepted from producers on this destination.  The message size includes the message body, any user-defined properties, and the user-defined JMS header fields: <tt>JMSCorrelationID</tt> and <tt>JMSType</tt> . Producers sending messages that exceed the configured maximum message size for the destination receive a <tt>ResourceAllocationException</tt> .  The maximum message size is only enforced for the initial production of a message. Messages that are redirected to an error destination or forwarded to a member of a distributed destination are not checked for size. For instance, if a destination and its corresponding error destination are configured with a maximum message size of 128K bytes and 64K bytes, respectively, a message of 96K bytes could be redirected to the error destination (even though it exceeds the 64K byte maximum), but a producer could not directly send the 96K byte message to the error destination.  This attribute is dynamically configurable, but only incoming messages are impacted; stored messages are not impacted.

  An example on how to use this:

      wls_jms_topic {a_wls_jms_topic :
         ...
         maximum_message_size => '2147483647'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_topic:maximum_message_size']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('MaximumMessageSize')
end
