#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  Type.newtype(:wls_machine) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-EOD
    This resource allows you to manage machine in an WebLogic domain.

    Here is an example on how you should use this:

        wls_machine { 'test2':
          ensure        => 'present',
          listenaddress => '10.10.10.10',
          listenport    => '5556',
          machinetype   => 'UnixMachine',
          nmtype        => 'SSL',
        }

    In this example you are managing a machine in the default domain. When you want to
    manage a machine in a specific domain, you can use:

        wls_machine { 'my_domain/test2':
          ensure        => 'present',
          listenaddress => '10.10.10.10',
          listenport    => '5556',
          machinetype   => 'UnixMachine',
          nmtype        => 'SSL',
        }

    EOD

    bean_type('Machine')

    on_create do
      Puppet.info "create #{machine_name} "
      wls_config = Puppet_X::EnterpriseModules::WebLogic::Tree.new(domain)
      if machinetype == :UnixMachine
        wls_config.create('UnixMachine', '/', machine_name)
      else
        wls_config.create('Machine', '/', machine_name)
      end
      nil
    end

    ensurable
    parameter :domain
    parameter :name
    parameter :machine_name
    parameter :timeout
    parameter :machinetype

    property  :nmtype
    property  :listenaddress
    property  :listenport

    extraproperties do
      property :adapter_name
      property :adapter
      property :adapter_version
      property :debug_enabled
      property :installed_vmm_adapters
      property :listen_address
      property :listen_port
      property :nm_type
      property :node_manager_home
      property :password
      property :shell_command
      property :user_name
      property :addresses
      property :notes
      property :post_bind_gid_enabled
      property :post_bind_gid
      property :post_bind_uid_enabled
      property :post_bind_uid
      #
      # Weblogic 12.2.1 new properties
      #
      property :tags
    end

    add_title_attributes(:machine_name)
  end
end
