#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  Type.newtype(:wls_security_policy) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc 'This resource allows you to manage security authorization policies in an WebLogic Security Realm.'

    ensurable

    to_get_raw_resources do
      raise " Non implemented"
    end

    on_prefetch do |resources, provider|
      resources.each do | name, resource|
        hash = resource.to_hash
        wls_config = Puppet_X::EnterpriseModules::WebLogic::Tree.new(hash[:domain])
        policyexpression = wls_config.get_security_policy(resource[:resourcetype], resource[:resourcename], resource[:operation])
        next if policyexpression.nil? 
        hash[:policyexpression] = policyexpression
        hash[:ensure] = :present
        resource.provider = provider.new(hash)
      end
      resources
    end

    on_create do
      Puppet.info "create #{name}"
      modify
      nil
    end

    on_modify do
      Puppet.info "modify #{name}"
      modify
    end

    on_destroy do
      Puppet.info "destroy #{name}"
      wls_config  = Puppet_X::EnterpriseModules::WebLogic::Tree.new(domain)
      wls_config.set_security_policy(resourcetype, resourcename, :absent)
      nil
    end

    def modify
      wls_config  = Puppet_X::EnterpriseModules::WebLogic::Tree.new(domain)
      wls_config.set_security_policy(resourcetype, resourcename, operation, policyexpression)
      nil
    end

    parameter :domain
    parameter :name
    parameter :resourcetype
    parameter :resourcename
    parameter :operation
    parameter :timeout
    property  :policyexpression

    add_title_attributes(:resourcetype, :resourcename, :operation) do
      /(.+):(.+):(.+)$/
    end

  end
end
