#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:startup_mode, :parent => Puppet::Parameter::WlsProperty) do

  desc <<-EOD
  The state in which this server should be started. If you specify <tt>STANDBY</tt>, you must also enable the domain-wide administration port.  In the <code>RUNNING</code> state, a server offers its services to clients and can operate as a full member of a cluster. In the <code>ADMIN</code> state, the server is up and running, but available only for administration operations, allowing you to perform server and application-level administration tasks without risk to running applications. In the <code>STANDBY</code> state, a server instance does not process any request; its regular Listen Port is closed. The Administration Port is open. It only accepts life cycle commands that transition the server instance to either the <code>RUNNING</code> or the <code>SHUTDOWN</code> state. Other Administration requests are not accepted. A <code>STANDBY</code> server's only purpose is to resume into the <code>RUNNING</code> state quickly; it saves server startup time. 

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         startup_mode => 'RUNNING'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:startup_mode']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('StartupMode')
end
