#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:use_detailed_thread_name, :parent => Puppet::Parameter::WlsProperty) do

  desc <<-EOD
  Whether to includes detail information in self-tuning thread pool thread names. Setting this flag on would include additional information such as the name of the work manager that the execute thread is executing task for, but at the expense of overhead in keeping the thread name updated with such information. 

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         use_detailed_thread_name => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:use_detailed_thread_name']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  maps_to('UseDetailedThreadName')
end
