#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:log_rotationtype, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-EOD
  Criteria for moving old log messages to a separate file.

  - `NONE` Messages accumulate in a single file. You must erase the contents of
  the file when the size is too large. Note that WebLogic Server sets a threshold
  size limit of 500 MB before it forces a hard rotation to prevent excessive log
  file growth.
  - `SIZE` When the log file reaches the size that you specify in `FileMinSize`,
  the server renames the file as `SERVER_NAME.lognnnnn`.
  - `TIME` At each time interval that you specify in `TimeSpan`, the server renames
  the file as `SERVER_NAME.lognnnnn`.

  After the server renames a file, subsequent messages accumulate in a new file
   with the name that you specified as the log file name.

  An example on how to use this:

      ...{...:
         ...
         log_rotationtype => bySize
         ...
      }

  Help text generated from MBEan text.


  EOD

  newvalues('absent', 'bySize', 'byTime', 'none')

  maps_to([
            'Log/%{server_name}/RotationType',
            'WebServer/%{server_name}/WebServerLog/%{server_name}/RotationType',
            'DataSource/%{server_name}/DataSourceLogFile/%{server_name}/RotationType'
          ])
end
